(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    142837,       2660]
NotebookOptionsPosition[    137618,       2566]
NotebookOutlinePosition[    138155,       2585]
CellTagsIndexPosition[    138112,       2582]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Polar Zonohedra", "Title",
 CellChangeTimes->{{3.7424155586061525`*^9, 3.7424155718219604`*^9}, {
  3.818173068676195*^9, 3.818173079231597*^9}, {3.820493671112155*^9, 
  3.820493676114018*^9}},ExpressionUUID->"5f92735f-b0fc-4fca-8341-\
d9dbb5db09b2"],

Cell["\<\
G. Hart, Dec. 2020.  Calculate face angles, dihedral angles, etc. of Polar \
Zonohedra.
Supplement to 2021 Bridges Conference Paper \[OpenCurlyDoubleQuote]The Joy of \
Polar Zonohedra\[CloseCurlyDoubleQuote]\
\>", "Text",
 CellChangeTimes->{{3.7424686181526375`*^9, 3.7424686429625373`*^9}, {
   3.7424686995985327`*^9, 3.7424687043115945`*^9}, {3.7424690941487064`*^9, 
   3.742469116950132*^9}, {3.7481162196691465`*^9, 3.748116229704941*^9}, {
   3.750608738526538*^9, 3.7506087490728045`*^9}, {3.80917629564869*^9, 
   3.8091763227960863`*^9}, {3.81817016291798*^9, 3.8181701861048775`*^9}, {
   3.81817035420133*^9, 3.818170358061492*^9}, {3.8181736815577354`*^9, 
   3.8181737223775406`*^9}, {3.818247347970214*^9, 3.81824734904084*^9}, {
   3.820493684919202*^9, 3.8204937037602377`*^9}, {3.8204939765661507`*^9, 
   3.8204939905476017`*^9}, {3.8204940206758566`*^9, 3.820494084691123*^9}, {
   3.820495554826166*^9, 3.8204955612527027`*^9}, 3.8204956056149545`*^9, {
   3.820495656262481*^9, 3.820495658445958*^9}, {3.8272481898280487`*^9, 
   3.827248207312538*^9}, {3.8272488251620197`*^9, 
   3.8272488292650023`*^9}},ExpressionUUID->"9741cc49-005f-4c5c-87ca-\
55a0abe28021"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"n", "=", "9"}], ";"}], "    ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Set", " ", "the", " ", "desired", " ", "n"}], "-", 
    RowBox[{"fold", " ", "symmetry", " ", "of", " ", "structure"}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"theta", "=", 
    RowBox[{"ArcTan", "[", 
     RowBox[{"1", "/", 
      RowBox[{"Sqrt", "[", "2", "]"}]}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
     "Set", " ", "the", " ", "desired", " ", "umbrella", " ", "closure", " ", 
      RowBox[{"angle", ":", " ", "0"}]}], "=", "pancake"}], ",", " ", 
    RowBox[{"90", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"cigar", ".", "  ", "This"}], " ", "is", " ", "the", " ", 
       "volume"}], "-", 
      RowBox[{"mazimizing", " ", 
       RowBox[{"angle", "."}]}]}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"g", "[", "i_", "]"}], ":=", "  ", 
    RowBox[{"(*", " ", 
     RowBox[{"unit", "-", 
      RowBox[{"length", " ", "generators"}]}], " ", "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", "theta", "]"}], 
        RowBox[{"Cos", "[", 
         RowBox[{"2", " ", "Pi", " ", 
          RowBox[{"i", "/", "n"}]}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", "theta", "]"}], 
        RowBox[{"Sin", "[", 
         RowBox[{"2", " ", "Pi", " ", 
          RowBox[{"i", "/", "n"}]}], "]"}]}], ",", 
       RowBox[{"Sin", "[", "theta", "]"}]}], "}"}], "//", "N"}]}], ";"}], 
  "     ", "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"angle", "[", "i_", "]"}], ":=", 
    RowBox[{
     RowBox[{"ArcCos", "[", 
      RowBox[{
       RowBox[{"g", "[", "0", "]"}], ".", 
       RowBox[{"g", "[", "i", "]"}]}], "]"}], "/", "Degree"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "\"\<top\>\"", " ", "angle", " ", "of", " ", "rhombic", " ", "faces", " ", 
    "at", " ", "level", " ", "i"}], " ", "*)"}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"dihedralAngle", "[", 
     RowBox[{"i_", ",", "j_", ",", "k_", ",", "l_"}], "]"}], ":=", " ", 
    RowBox[{"(*", " ", 
     RowBox[{
     "angle", " ", "between", " ", "face", " ", "with", " ", "directions", 
      " ", "i", " ", "and", " ", "j", " ", "and", " ", "the", " ", "face", 
      " ", "with", " ", "directions", " ", "k", " ", "and", " ", "l"}], " ", 
     "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ArcCos", "[", 
      RowBox[{
       RowBox[{"Normalize", "[", 
        RowBox[{"Cross", "[", 
         RowBox[{
          RowBox[{"g", "[", "i", "]"}], ",", 
          RowBox[{"g", "[", "j", "]"}]}], "]"}], "]"}], ".", 
       RowBox[{"Normalize", "[", 
        RowBox[{"Cross", "[", 
         RowBox[{
          RowBox[{"g", "[", "k", "]"}], ",", 
          RowBox[{"g", "[", "l", "]"}]}], "]"}], "]"}]}], "]"}], "/", 
     "Degree"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"dihedralAtLevel", "[", "1", "]"}], "=", 
    RowBox[{"dihedralAngle", "[", 
     RowBox[{"1", ",", "2", ",", "2", ",", "3"}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "the", " ", "tips", " ", "are", " ", "a", " ", "special", " ", "case"}], 
   " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"dihedralAtLevel", "[", "i_", "]"}], "=", 
    RowBox[{"dihedralAngle", "[", 
     RowBox[{"1", ",", "i", ",", "1", ",", 
      RowBox[{"i", "+", "1"}]}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"general", " ", "case", " ", "for", " ", "i"}], ">", "1"}], " ", 
   "*)"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<Face Angles: \>\"", ",", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"angle", "[", "i", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<Dihedral Angles: \>\"", ",", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"dihedralAtLevel", "[", "i", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.598107406996293*^9, 3.598107420315055*^9}, {
   3.5981074506227884`*^9, 3.5981074552270517`*^9}, {3.5981075114312663`*^9, 
   3.5981080924504986`*^9}, {3.5981081487547193`*^9, 
   3.5981081970694823`*^9}, {3.5981088081224327`*^9, 
   3.5981088144417944`*^9}, {3.598108995792206*^9, 3.5981090127022295`*^9}, {
   3.5981093376399693`*^9, 3.598109353699992*^9}, {3.598110526781207*^9, 
   3.5981105269312077`*^9}, {3.5981105722212706`*^9, 
   3.5981106385313635`*^9}, {3.5981107603015337`*^9, 3.598110789471575*^9}, {
   3.59811082895163*^9, 3.5981108419016485`*^9}, {3.5981108748519783`*^9, 
   3.5981108894419985`*^9}, {3.598743217958669*^9, 3.5987432303286867`*^9}, 
   3.5987434471199903`*^9, {3.74241560336129*^9, 3.7424156610767736`*^9}, {
   3.742415691446594*^9, 3.7424156962479467`*^9}, {3.742415743777521*^9, 
   3.742415744979796*^9}, {3.7424158539316764`*^9, 3.74241585754666*^9}, {
   3.74241591373368*^9, 3.7424160229627523`*^9}, {3.742416168531171*^9, 
   3.7424161726781554`*^9}, {3.7424162384245706`*^9, 
   3.7424163497637267`*^9}, {3.742416408840589*^9, 3.742416585524789*^9}, {
   3.742466128717268*^9, 3.742466286896056*^9}, {3.7424663414944696`*^9, 
   3.742466347658221*^9}, {3.7424664602042093`*^9, 3.742466560817322*^9}, {
   3.7424666225081844`*^9, 3.7424666722097197`*^9}, {3.742466738107522*^9, 
   3.742466928818257*^9}, 3.742467047498809*^9, {3.7424670909195476`*^9, 
   3.7424671337718596`*^9}, {3.7424671866217694`*^9, 
   3.7424671867751303`*^9}, {3.7424672188434277`*^9, 
   3.7424673007139673`*^9}, {3.7424673316840897`*^9, 3.742467746076935*^9}, {
   3.7424678298664675`*^9, 3.7424678324218397`*^9}, {3.7424678728054976`*^9, 
   3.7424680491092677`*^9}, {3.74246809570716*^9, 3.7424682659638853`*^9}, {
   3.742468308389202*^9, 3.7424683592602763`*^9}, {3.742468431423258*^9, 
   3.74246850403438*^9}, {3.742468743228099*^9, 3.7424688257943687`*^9}, {
   3.7424688577972317`*^9, 3.742468858151528*^9}, {3.7424689022097855`*^9, 
   3.74246895395465*^9}, 3.742469038671302*^9, {3.742469869496521*^9, 
   3.7424698700198927`*^9}, {3.742470224168907*^9, 3.742470235989623*^9}, {
   3.742473380312688*^9, 3.7424735027107506`*^9}, {3.7424755340255566`*^9, 
   3.74247560204946*^9}, {3.742475719039362*^9, 3.7424757960593767`*^9}, 
   3.7424759797284756`*^9, {3.742476028493613*^9, 3.742476075134173*^9}, {
   3.7481162443851633`*^9, 3.7481162990673018`*^9}, {3.748116331835225*^9, 
   3.7481163926579027`*^9}, {3.748116959315838*^9, 3.748117036863092*^9}, {
   3.7481170701529393`*^9, 3.74811709674594*^9}, {3.7481172044150476`*^9, 
   3.7481172515926003`*^9}, {3.7481172961424336`*^9, 
   3.7481172975424957`*^9}, {3.7481173291422377`*^9, 
   3.7481173294524107`*^9}, {3.7481173818651433`*^9, 3.748117417002514*^9}, {
   3.748117506184227*^9, 3.7481175378639526`*^9}, 3.748117680671161*^9, {
   3.7481183533525224`*^9, 3.7481183545795803`*^9}, {3.748118384872419*^9, 
   3.748118414630022*^9}, 3.7482644613634057`*^9, {3.7482645500678463`*^9, 
   3.7482645506768637`*^9}, {3.748264734745276*^9, 3.7482647869453645`*^9}, {
   3.748290999922058*^9, 3.74829106906816*^9}, {3.7482911046727333`*^9, 
   3.748291109469496*^9}, {3.748377222657501*^9, 3.7483772520779495`*^9}, {
   3.748377651229847*^9, 3.7483776699630804`*^9}, {3.7483777264602776`*^9, 
   3.7483777572397804`*^9}, {3.748377793722457*^9, 3.748377793847437*^9}, {
   3.7483778392046223`*^9, 3.748377878890038*^9}, {3.748432346356146*^9, 
   3.7484324117902203`*^9}, 3.748432455406406*^9, {3.7484324912166433`*^9, 
   3.7484325159400606`*^9}, {3.748432651481883*^9, 3.7484326578405437`*^9}, {
   3.7506069557988763`*^9, 3.7506069830006647`*^9}, 3.7506070254985743`*^9, 
   3.809176614187207*^9, 3.8091768546055965`*^9, {3.8091769021999264`*^9, 
   3.8091769278454003`*^9}, {3.818170368493853*^9, 3.8181703699282703`*^9}, {
   3.8181704775337725`*^9, 3.8181705302260265`*^9}, {3.818170578678239*^9, 
   3.818170583951112*^9}, {3.818170618468474*^9, 3.818170637427462*^9}, {
   3.8181709228764477`*^9, 3.818170968260739*^9}, {3.8181731108658032`*^9, 
   3.818173120485837*^9}, {3.818173165402233*^9, 3.818173187481682*^9}, 
   3.8181732354852347`*^9, {3.8181733009009714`*^9, 3.8181733110165386`*^9}, {
   3.818173420458703*^9, 3.8181734324350033`*^9}, {3.8181734728543096`*^9, 
   3.818173495661174*^9}, {3.818173543745299*^9, 3.818173666025067*^9}, {
   3.818174174335066*^9, 3.818174192368271*^9}, 3.818174300003851*^9, {
   3.8181743571695375`*^9, 3.8181744099311647`*^9}, {3.818174473298829*^9, 
   3.8181744762140794`*^9}, {3.8181745101182394`*^9, 
   3.8181745718009777`*^9}, {3.818174608305853*^9, 3.818174626063266*^9}, {
   3.8181747161019745`*^9, 3.8181747249633894`*^9}, {3.818174758801505*^9, 
   3.8181747778617496`*^9}, {3.8181748673768644`*^9, 
   3.8181749063214817`*^9}, {3.8181749419939814`*^9, 
   3.8181750244593277`*^9}, {3.8181750862482996`*^9, 
   3.8181752113610153`*^9}, {3.818175245552536*^9, 3.818175245643902*^9}, {
   3.8181753222609053`*^9, 3.8181753224234505`*^9}, {3.818175838091198*^9, 
   3.8181758498297205`*^9}, {3.8181759063517256`*^9, 
   3.8181759191941013`*^9}, {3.818176031898213*^9, 3.818176045839857*^9}, {
   3.818176591463786*^9, 3.818176609548948*^9}, {3.8181766887084665`*^9, 
   3.8181767177784786`*^9}, {3.818176867543849*^9, 3.818176912687746*^9}, {
   3.8181769608888493`*^9, 3.8181769639175367`*^9}, {3.8181784830776653`*^9, 
   3.818178484395566*^9}, {3.818178523917779*^9, 3.8181785349038973`*^9}, {
   3.8182453477170258`*^9, 3.818245384656392*^9}, {3.8182492750820765`*^9, 
   3.8182492926067142`*^9}, 3.8182493874599457`*^9, {3.8182556476208715`*^9, 
   3.818255647705645*^9}, {3.818318822691266*^9, 3.8183188506485133`*^9}, 
   3.818322343079779*^9, {3.818322410602498*^9, 3.81832241082473*^9}, 
   3.81832253638556*^9, 3.818322969270839*^9, {3.818331307805892*^9, 
   3.8183313079058046`*^9}, {3.818600147140417*^9, 3.8186002227203903`*^9}, {
   3.818601234980243*^9, 3.8186012649835863`*^9}, 3.818601425852751*^9, {
   3.8186014992282014`*^9, 3.8186015447531843`*^9}, {3.8186017609710116`*^9, 
   3.818601828048644*^9}, {3.8186018736770735`*^9, 3.8186019027929626`*^9}, {
   3.818703306728774*^9, 3.818703325163285*^9}, {3.819040595783749*^9, 
   3.8190405962246933`*^9}, {3.8190406641146126`*^9, 
   3.8190406645524645`*^9}, {3.819040772830756*^9, 3.819040785943429*^9}, 
   3.8190408607014203`*^9, 3.819810970527158*^9, 3.8198111419911265`*^9, {
   3.8204937197067084`*^9, 3.8204937753856583`*^9}, {3.8204938295168257`*^9, 
   3.8204938578017006`*^9}, {3.820493896176701*^9, 3.820493930867417*^9}, {
   3.820494124101053*^9, 3.820494245260543*^9}, {3.8204942806271787`*^9, 
   3.820494458421057*^9}, 3.8204953369497523`*^9, {3.8272483319569674`*^9, 
   3.8272483321215563`*^9}},
 CellLabel->"In[19]:=",ExpressionUUID->"cc56daf7-85ec-4c21-a4a3-98dd1c8ed991"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Face Angles: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "32.43188279568316`", ",", "63.31412237136685`", ",", "90.`", ",", 
     "107.04534275253073`", ",", "107.04534275253073`", ",", "90.`", ",", 
     "63.31412237136685`", ",", "32.43188279568316`"}], "}"}]}],
  SequenceForm[
  "Face Angles: ", {32.43188279568316, 63.31412237136685, 90., 
   107.04534275253073`, 107.04534275253073`, 90., 63.31412237136685, 
   32.43188279568316}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.8181749837724915`*^9, 3.8181750248751836`*^9}, {
   3.8181750880379367`*^9, 3.818175099711542*^9}, {3.8181751781709957`*^9, 
   3.8181752126014767`*^9}, 3.81817524650882*^9, 3.8181753242075243`*^9, 
   3.818175857347254*^9, {3.8181766923613667`*^9, 3.8181767187796917`*^9}, {
   3.8181768684669538`*^9, 3.818176913389721*^9}, 3.8181769651514497`*^9, 
   3.818178485820052*^9, {3.8181785264763536`*^9, 3.8181785355582247`*^9}, 
   3.818245406029992*^9, {3.818249276052643*^9, 3.8182492935238028`*^9}, 
   3.818249388797969*^9, 3.818255649076888*^9, {3.8183188453484426`*^9, 
   3.818318851935198*^9}, 3.81832234496129*^9, 3.8183224125765886`*^9, 
   3.818322537535627*^9, 3.8183229709914727`*^9, 3.818331309505538*^9, 
   3.8183424450313377`*^9, 3.8183427780966487`*^9, {3.8186002079712563`*^9, 
   3.818600223138343*^9}, 3.8186012711484814`*^9, 3.8186014275337443`*^9, 
   3.8186015046796513`*^9, {3.818601808426829*^9, 3.8186018286352587`*^9}, {
   3.8186018764317427`*^9, 3.8186019040104303`*^9}, 3.8187031226875095`*^9, {
   3.818703307817377*^9, 3.818703327190267*^9}, 3.819040600372566*^9, 
   3.8190407889414196`*^9, 3.819810973448701*^9, 3.8198111429405427`*^9, 
   3.820494258825828*^9, 3.820494294424013*^9, 3.8204943561118865`*^9, 
   3.8204944917532253`*^9, 3.820495315798893*^9, 3.820495479811013*^9, 
   3.827248222904792*^9, 3.8272483526688423`*^9},
 CellLabel->
  "During evaluation of \
In[19]:=",ExpressionUUID->"d92343a6-712f-4134-8fc2-39ba16bcba0d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Dihedral Angles: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "23.734737851548545`", ",", "13.980703186104884`", ",", 
     "19.15192788812083`", ",", "28.01694665403135`", ",", 
     "33.96610669193723`", ",", "28.01694665403138`", ",", 
     "19.151927888120852`", ",", "13.980703186104991`"}], "}"}]}],
  SequenceForm[
  "Dihedral Angles: ", {23.734737851548545`, 13.980703186104884`, 
   19.15192788812083, 28.01694665403135, 33.96610669193723, 28.01694665403138,
    19.151927888120852`, 13.980703186104991`}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.8181749837724915`*^9, 3.8181750248751836`*^9}, {
   3.8181750880379367`*^9, 3.818175099711542*^9}, {3.8181751781709957`*^9, 
   3.8181752126014767`*^9}, 3.81817524650882*^9, 3.8181753242075243`*^9, 
   3.818175857347254*^9, {3.8181766923613667`*^9, 3.8181767187796917`*^9}, {
   3.8181768684669538`*^9, 3.818176913389721*^9}, 3.8181769651514497`*^9, 
   3.818178485820052*^9, {3.8181785264763536`*^9, 3.8181785355582247`*^9}, 
   3.818245406029992*^9, {3.818249276052643*^9, 3.8182492935238028`*^9}, 
   3.818249388797969*^9, 3.818255649076888*^9, {3.8183188453484426`*^9, 
   3.818318851935198*^9}, 3.81832234496129*^9, 3.8183224125765886`*^9, 
   3.818322537535627*^9, 3.8183229709914727`*^9, 3.818331309505538*^9, 
   3.8183424450313377`*^9, 3.8183427780966487`*^9, {3.8186002079712563`*^9, 
   3.818600223138343*^9}, 3.8186012711484814`*^9, 3.8186014275337443`*^9, 
   3.8186015046796513`*^9, {3.818601808426829*^9, 3.8186018286352587`*^9}, {
   3.8186018764317427`*^9, 3.8186019040104303`*^9}, 3.8187031226875095`*^9, {
   3.818703307817377*^9, 3.818703327190267*^9}, 3.819040600372566*^9, 
   3.8190407889414196`*^9, 3.819810973448701*^9, 3.8198111429405427`*^9, 
   3.820494258825828*^9, 3.820494294424013*^9, 3.8204943561118865`*^9, 
   3.8204944917532253`*^9, 3.820495315798893*^9, 3.820495479811013*^9, 
   3.827248222904792*^9, 3.827248352672702*^9},
 CellLabel->
  "During evaluation of \
In[19]:=",ExpressionUUID->"0b91bb84-2c1e-40ac-bcdd-b0a55688b8f2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Render", "Section",
 CellChangeTimes->{{3.818174791025922*^9, 
  3.818174798423671*^9}},ExpressionUUID->"a49accf5-835d-4afc-b7b8-\
a1922f8b6cd0"],

Cell["\<\
Each vertex is a connected sum of generators, e.g., g[4]+g[5]+g[6]+g[7], so \
we name each vertex by the starting and ending index, with i\[LessEqual]j, in \
this example: 4 and 7.
Can use any pair with i>j to code the starting pole, i.e., the empty sum \
gives the origin.\
\>", "Text",
 CellChangeTimes->{{3.7424686181526375`*^9, 3.7424686429625373`*^9}, {
  3.7424686995985327`*^9, 3.7424687043115945`*^9}, {3.7424690941487064`*^9, 
  3.742469116950132*^9}, {3.7481162196691465`*^9, 3.748116229704941*^9}, {
  3.750608738526538*^9, 3.7506087490728045`*^9}, {3.80917629564869*^9, 
  3.8091763227960863`*^9}, {3.81817016291798*^9, 3.8181701861048775`*^9}, {
  3.81817035420133*^9, 3.818170358061492*^9}, {3.8181736815577354`*^9, 
  3.8181737223775406`*^9}, {3.818245670507663*^9, 3.818245762686824*^9}, {
  3.8182460650513287`*^9, 3.818246120503933*^9}, {3.818246856964031*^9, 
  3.818246882148128*^9}, {3.818246936681531*^9, 3.8182470012699537`*^9}, {
  3.8182488253005347`*^9, 3.818248829307958*^9}, {3.818248871236313*^9, 
  3.818248932620636*^9}},ExpressionUUID->"0d5c0048-1123-4607-834f-\
fb69adcb6861"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"v", "[", 
     RowBox[{"i_", ",", "j_"}], "]"}], ":=", " ", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"i", ">", "j"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", " ", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{"g", "[", "k", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "i", ",", "j"}], "}"}]}], "]"}]}], "]"}]}], ";"}], 
  "    ", 
  RowBox[{"(*", " ", 
   RowBox[{"XYZ", " ", "coords", " ", "of", " ", "ijth", " ", "vertex"}], " ",
    "*)"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"face", "[", 
    RowBox[{"i_", ",", "j_"}], "]"}], ":=", 
   RowBox[{"Polygon", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"v", "[", 
       RowBox[{"i", ",", "j"}], "]"}], ",", 
      RowBox[{"v", "[", 
       RowBox[{
        RowBox[{"i", "+", "1"}], ",", "j"}], "]"}], ",", 
      RowBox[{"v", "[", 
       RowBox[{
        RowBox[{"i", "+", "1"}], ",", 
        RowBox[{"j", "-", "1"}]}], "]"}], ",", 
      RowBox[{"v", "[", 
       RowBox[{"i", ",", 
        RowBox[{"j", "-", "1"}]}], "]"}]}], "}"}], "]"}]}], ";", " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "face", " ", "with", " ", "furthest", " ", "point", " ", "at", " ", "ij"}],
    " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Graphics3D", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"face", "[", 
       RowBox[{"i", ",", "j"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "n"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", 
        RowBox[{"i", "+", "1"}], ",", 
        RowBox[{"i", "+", "n", "-", "1"}]}], "}"}]}], "]"}], ",", " ", 
    RowBox[{"Boxed", "\[Rule]", "False"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.598107406996293*^9, 3.598107420315055*^9}, {
   3.5981074506227884`*^9, 3.5981074552270517`*^9}, {3.5981075114312663`*^9, 
   3.5981080924504986`*^9}, {3.5981081487547193`*^9, 
   3.5981081970694823`*^9}, {3.5981088081224327`*^9, 
   3.5981088144417944`*^9}, {3.598108995792206*^9, 3.5981090127022295`*^9}, {
   3.5981093376399693`*^9, 3.598109353699992*^9}, {3.598110526781207*^9, 
   3.5981105269312077`*^9}, {3.5981105722212706`*^9, 
   3.5981106385313635`*^9}, {3.5981107603015337`*^9, 3.598110789471575*^9}, {
   3.59811082895163*^9, 3.5981108419016485`*^9}, {3.5981108748519783`*^9, 
   3.5981108894419985`*^9}, {3.598743217958669*^9, 3.5987432303286867`*^9}, 
   3.5987434471199903`*^9, {3.74241560336129*^9, 3.7424156610767736`*^9}, {
   3.742415691446594*^9, 3.7424156962479467`*^9}, {3.742415743777521*^9, 
   3.742415744979796*^9}, {3.7424158539316764`*^9, 3.74241585754666*^9}, {
   3.74241591373368*^9, 3.7424160229627523`*^9}, {3.742416168531171*^9, 
   3.7424161726781554`*^9}, {3.7424162384245706`*^9, 
   3.7424163497637267`*^9}, {3.742416408840589*^9, 3.742416585524789*^9}, {
   3.742466128717268*^9, 3.742466286896056*^9}, {3.7424663414944696`*^9, 
   3.742466347658221*^9}, {3.7424664602042093`*^9, 3.742466560817322*^9}, {
   3.7424666225081844`*^9, 3.7424666722097197`*^9}, {3.742466738107522*^9, 
   3.742466928818257*^9}, 3.742467047498809*^9, {3.7424670909195476`*^9, 
   3.7424671337718596`*^9}, {3.7424671866217694`*^9, 
   3.7424671867751303`*^9}, {3.7424672188434277`*^9, 
   3.7424673007139673`*^9}, {3.7424673316840897`*^9, 3.742467746076935*^9}, {
   3.7424678298664675`*^9, 3.7424678324218397`*^9}, {3.7424678728054976`*^9, 
   3.7424680491092677`*^9}, {3.74246809570716*^9, 3.7424682659638853`*^9}, {
   3.742468308389202*^9, 3.7424683592602763`*^9}, {3.742468431423258*^9, 
   3.74246850403438*^9}, {3.742468743228099*^9, 3.7424688257943687`*^9}, {
   3.7424688577972317`*^9, 3.742468858151528*^9}, {3.7424689022097855`*^9, 
   3.74246895395465*^9}, 3.742469038671302*^9, {3.742469869496521*^9, 
   3.7424698700198927`*^9}, {3.742470224168907*^9, 3.742470235989623*^9}, {
   3.742473380312688*^9, 3.7424735027107506`*^9}, {3.7424755340255566`*^9, 
   3.74247560204946*^9}, {3.742475719039362*^9, 3.7424757960593767`*^9}, 
   3.7424759797284756`*^9, {3.742476028493613*^9, 3.742476075134173*^9}, {
   3.7481162443851633`*^9, 3.7481162990673018`*^9}, {3.748116331835225*^9, 
   3.7481163926579027`*^9}, {3.748116959315838*^9, 3.748117036863092*^9}, {
   3.7481170701529393`*^9, 3.74811709674594*^9}, {3.7481172044150476`*^9, 
   3.7481172515926003`*^9}, {3.7481172961424336`*^9, 
   3.7481172975424957`*^9}, {3.7481173291422377`*^9, 
   3.7481173294524107`*^9}, {3.7481173818651433`*^9, 3.748117417002514*^9}, {
   3.748117506184227*^9, 3.7481175378639526`*^9}, 3.748117680671161*^9, {
   3.7481183533525224`*^9, 3.7481183545795803`*^9}, {3.748118384872419*^9, 
   3.748118414630022*^9}, 3.7482644613634057`*^9, {3.7482645500678463`*^9, 
   3.7482645506768637`*^9}, {3.748264734745276*^9, 3.7482647869453645`*^9}, {
   3.748290999922058*^9, 3.74829106906816*^9}, {3.7482911046727333`*^9, 
   3.748291109469496*^9}, {3.748377222657501*^9, 3.7483772520779495`*^9}, {
   3.748377651229847*^9, 3.7483776699630804`*^9}, {3.7483777264602776`*^9, 
   3.7483777572397804`*^9}, {3.748377793722457*^9, 3.748377793847437*^9}, {
   3.7483778392046223`*^9, 3.748377878890038*^9}, {3.748432346356146*^9, 
   3.7484324117902203`*^9}, 3.748432455406406*^9, {3.7484324912166433`*^9, 
   3.7484325159400606`*^9}, {3.748432651481883*^9, 3.7484326578405437`*^9}, {
   3.7506069557988763`*^9, 3.7506069830006647`*^9}, 3.7506070254985743`*^9, 
   3.809176614187207*^9, 3.8091768546055965`*^9, {3.8091769021999264`*^9, 
   3.8091769278454003`*^9}, {3.818170368493853*^9, 3.8181703699282703`*^9}, {
   3.8181704775337725`*^9, 3.8181705302260265`*^9}, {3.818170578678239*^9, 
   3.818170583951112*^9}, {3.818170618468474*^9, 3.818170637427462*^9}, {
   3.8181709228764477`*^9, 3.818170968260739*^9}, {3.8181731108658032`*^9, 
   3.818173120485837*^9}, {3.818173165402233*^9, 3.818173187481682*^9}, 
   3.8181732354852347`*^9, {3.8181733009009714`*^9, 3.8181733110165386`*^9}, {
   3.818173420458703*^9, 3.8181734324350033`*^9}, {3.8181734728543096`*^9, 
   3.818173495661174*^9}, {3.818173543745299*^9, 3.818173666025067*^9}, {
   3.818174174335066*^9, 3.818174192368271*^9}, 3.818174300003851*^9, {
   3.8181743571695375`*^9, 3.8181744099311647`*^9}, {3.818174473298829*^9, 
   3.8181744762140794`*^9}, {3.8181745101182394`*^9, 
   3.8181745718009777`*^9}, {3.818174608305853*^9, 3.818174626063266*^9}, {
   3.8181747161019745`*^9, 3.8181747249633894`*^9}, {3.818174758801505*^9, 
   3.8181747778617496`*^9}, 3.8181768104421415`*^9, 3.8181769516130114`*^9, {
   3.818245771663685*^9, 3.818245787182858*^9}, {3.8182458471047015`*^9, 
   3.818245978617646*^9}, {3.818246011994299*^9, 3.8182460356346116`*^9}, {
   3.8182461427741213`*^9, 3.818246155227042*^9}, {3.818246752759105*^9, 
   3.818246756012037*^9}, {3.8182468169559603`*^9, 3.8182468382329493`*^9}, {
   3.818246879421549*^9, 3.8182469114474025`*^9}, {3.818249166631078*^9, 
   3.8182491796162033`*^9}, {3.8182493409227586`*^9, 3.818249345535768*^9}, {
   3.819811146966066*^9, 3.819811152793259*^9}, 3.8204945260772495`*^9, {
   3.8272484277138424`*^9, 3.8272484278807154`*^9}},
 CellLabel->"In[28]:=",ExpressionUUID->"c2ccea3a-b5f8-4086-88f1-aee45c0d9f24"],

Cell[BoxData[
 Graphics3DBox[{{
    Polygon3DBox[{{0.7672558119947084, 1.3289260487773493`, 
      1.1547005383792517`}, {0.14178314334937894`, 0.8040921632055843, 
      0.5773502691896258}, {0, 0, 0}, {0.6254726686453295, 0.524833885571765, 
      0.5773502691896258}}], 
    Polygon3DBox[{{0.3590075215308453, 2.036032829963897, 
     1.7320508075688776`}, {-0.2664651471144841, 1.5111989443921319`, 
     1.1547005383792517`}, {0.14178314334937894`, 0.8040921632055843, 
     0.5773502691896258}, {0.7672558119947084, 1.3289260487773493`, 
     1.1547005383792517`}}], 
    Polygon3DBox[{{-0.40824829046386313`, 2.315291107597716, 
     2.3094010767585034`}, {-1.0337209591091927`, 1.7904572220259511`, 
     1.7320508075688776`}, {-0.2664651471144841, 1.5111989443921319`, 
     1.1547005383792517`}, {0.3590075215308453, 2.036032829963897, 
     1.7320508075688776`}}], 
    Polygon3DBox[{{-1.1755041024585717`, 2.036032829963897, 
     2.886751345948129}, {-1.800976771103901, 1.5111989443921319`, 
     2.3094010767585034`}, {-1.0337209591091927`, 1.7904572220259511`, 
     1.7320508075688776`}, {-0.40824829046386313`, 2.315291107597716, 
     2.3094010767585034`}}], 
    Polygon3DBox[{{-1.5837523929224349`, 1.3289260487773493`, 
     3.4641016151377553`}, {-2.209225061567764, 0.8040921632055844, 
     2.886751345948129}, {-1.800976771103901, 1.5111989443921319`, 
     2.3094010767585034`}, {-1.1755041024585717`, 2.036032829963897, 
     2.886751345948129}}], 
    Polygon3DBox[{{-1.4419692495730556`, 0.5248338855717649, 
     4.0414518843273814`}, {-2.0674419182183854`, 2.220446049250313*^-16, 
     3.4641016151377553`}, {-2.209225061567764, 0.8040921632055844, 
     2.886751345948129}, {-1.5837523929224349`, 1.3289260487773493`, 
     3.4641016151377553`}}], 
    Polygon3DBox[{{-0.8164965809277263, 0., 
     4.618802153517007}, {-1.4419692495730558`, -0.5248338855717649, 
     4.0414518843273814`}, {-2.0674419182183854`, 2.220446049250313*^-16, 
     3.4641016151377553`}, {-1.4419692495730556`, 0.5248338855717649, 
     4.0414518843273814`}}], 
    Polygon3DBox[{{-4.440892098500626*^-16, 0., 
     5.196152422706632}, {-0.6254726686453298, -0.5248338855717649, 
     4.618802153517007}, {-1.4419692495730558`, -0.5248338855717649, 
     4.0414518843273814`}, {-0.8164965809277263, 0., 4.618802153517007}}]}, {
    Polygon3DBox[{{-0.2664651471144841, 1.5111989443921319`, 
      1.1547005383792517`}, {-0.4082482904638631, 0.7071067811865475, 
      0.5773502691896258}, {0, 0, 0}, {0.14178314334937894`, 
      0.8040921632055843, 0.5773502691896258}}], 
    Polygon3DBox[{{-1.0337209591091927`, 1.7904572220259511`, 
     1.7320508075688776`}, {-1.1755041024585715`, 0.9863650588203667, 
     1.1547005383792517`}, {-0.4082482904638631, 0.7071067811865475, 
     0.5773502691896258}, {-0.2664651471144841, 1.5111989443921319`, 
     1.1547005383792517`}}], 
    Polygon3DBox[{{-1.800976771103901, 1.5111989443921319`, 
     2.3094010767585034`}, {-1.94275991445328, 0.7071067811865475, 
     1.7320508075688776`}, {-1.1755041024585715`, 0.9863650588203667, 
     1.1547005383792517`}, {-1.0337209591091927`, 1.7904572220259511`, 
     1.7320508075688776`}}], 
    Polygon3DBox[{{-2.209225061567764, 0.8040921632055844, 
     2.886751345948129}, {-2.351008204917143, 0., 
     2.3094010767585034`}, {-1.94275991445328, 0.7071067811865475, 
     1.7320508075688776`}, {-1.800976771103901, 1.5111989443921319`, 
     2.3094010767585034`}}], 
    Polygon3DBox[{{-2.0674419182183854`, 2.220446049250313*^-16, 
     3.4641016151377553`}, {-2.209225061567764, -0.8040921632055844, 
     2.886751345948129}, {-2.351008204917143, 0., 
     2.3094010767585034`}, {-2.209225061567764, 0.8040921632055844, 
     2.886751345948129}}], 
    Polygon3DBox[{{-1.4419692495730558`, -0.5248338855717649, 
     4.0414518843273814`}, {-1.5837523929224346`, -1.3289260487773493`, 
     3.4641016151377553`}, {-2.209225061567764, -0.8040921632055844, 
     2.886751345948129}, {-2.0674419182183854`, 2.220446049250313*^-16, 
     3.4641016151377553`}}], 
    Polygon3DBox[{{-0.6254726686453298, -0.5248338855717649, 
     4.618802153517007}, {-0.7672558119947086, -1.3289260487773493`, 
     4.0414518843273814`}, {-1.5837523929224346`, -1.3289260487773493`, 
     3.4641016151377553`}, {-1.4419692495730558`, -0.5248338855717649, 
     4.0414518843273814`}}], 
    Polygon3DBox[{{-4.440892098500626*^-16, 1.1102230246251565`*^-16, 
     5.196152422706632}, {-0.14178314334937925`, -0.8040921632055843, 
     4.618802153517007}, {-0.7672558119947086, -1.3289260487773493`, 
     4.0414518843273814`}, {-0.6254726686453298, -0.5248338855717649, 
     4.618802153517007}}]}, {
    Polygon3DBox[{{-1.1755041024585715`, 0.9863650588203667, 
      1.1547005383792517`}, {-0.7672558119947085, 0.27925827763381933`, 
      0.5773502691896258}, {0, 0, 0}, {-0.4082482904638631, 
      0.7071067811865475, 0.5773502691896258}}], 
    Polygon3DBox[{{-1.94275991445328, 0.7071067811865475, 
     1.7320508075688776`}, {-1.534511623989417, 0., 
     1.1547005383792517`}, {-0.7672558119947085, 0.27925827763381933`, 
     0.5773502691896258}, {-1.1755041024585715`, 0.9863650588203667, 
     1.1547005383792517`}}], 
    Polygon3DBox[{{-2.351008204917143, 0., 
     2.3094010767585034`}, {-1.9427599144532801`, -0.7071067811865475, 
     1.7320508075688776`}, {-1.534511623989417, 0., 
     1.1547005383792517`}, {-1.94275991445328, 0.7071067811865475, 
     1.7320508075688776`}}], 
    Polygon3DBox[{{-2.209225061567764, -0.8040921632055844, 
     2.886751345948129}, {-1.800976771103901, -1.5111989443921319`, 
     2.3094010767585034`}, {-1.9427599144532801`, -0.7071067811865475, 
     1.7320508075688776`}, {-2.351008204917143, 0., 2.3094010767585034`}}], 
    Polygon3DBox[{{-1.5837523929224346`, -1.3289260487773493`, 
     3.4641016151377553`}, {-1.1755041024585717`, -2.036032829963897, 
     2.886751345948129}, {-1.800976771103901, -1.5111989443921319`, 
     2.3094010767585034`}, {-2.209225061567764, -0.8040921632055844, 
     2.886751345948129}}], 
    Polygon3DBox[{{-0.7672558119947086, -1.3289260487773493`, 
     4.0414518843273814`}, {-0.3590075215308457, -2.036032829963897, 
     3.4641016151377553`}, {-1.1755041024585717`, -2.036032829963897, 
     2.886751345948129}, {-1.5837523929224346`, -1.3289260487773493`, 
     3.4641016151377553`}}], 
    Polygon3DBox[{{-0.14178314334937925`, -0.8040921632055843, 
     4.618802153517007}, {0.2664651471144839, -1.5111989443921319`, 
     4.0414518843273814`}, {-0.3590075215308457, -2.036032829963897, 
     3.4641016151377553`}, {-0.7672558119947086, -1.3289260487773493`, 
     4.0414518843273814`}}], 
    Polygon3DBox[{{-4.440892098500626*^-16, -1.1102230246251565`*^-16, 
     5.196152422706632}, {0.4082482904638627, -0.7071067811865476, 
     4.618802153517007}, {0.2664651471144839, -1.5111989443921319`, 
     4.0414518843273814`}, {-0.14178314334937925`, -0.8040921632055843, 
     4.618802153517007}}]}, {
    Polygon3DBox[{{-1.534511623989417, 0., 
      1.1547005383792517`}, {-0.7672558119947085, -0.27925827763381933`, 
      0.5773502691896258}, {0, 0, 0}, {-0.7672558119947085, 
      0.27925827763381933`, 0.5773502691896258}}], 
    Polygon3DBox[{{-1.9427599144532801`, -0.7071067811865475, 
     1.7320508075688776`}, {-1.1755041024585715`, -0.9863650588203667, 
     1.1547005383792517`}, {-0.7672558119947085, -0.27925827763381933`, 
     0.5773502691896258}, {-1.534511623989417, 0., 1.1547005383792517`}}], 
    Polygon3DBox[{{-1.800976771103901, -1.5111989443921319`, 
     2.3094010767585034`}, {-1.0337209591091925`, -1.790457222025951, 
     1.7320508075688776`}, {-1.1755041024585715`, -0.9863650588203667, 
     1.1547005383792517`}, {-1.9427599144532801`, -0.7071067811865475, 
     1.7320508075688776`}}], 
    Polygon3DBox[{{-1.1755041024585717`, -2.036032829963897, 
     2.886751345948129}, {-0.40824829046386313`, -2.315291107597716, 
     2.3094010767585034`}, {-1.0337209591091925`, -1.790457222025951, 
     1.7320508075688776`}, {-1.800976771103901, -1.5111989443921319`, 
     2.3094010767585034`}}], 
    Polygon3DBox[{{-0.3590075215308457, -2.036032829963897, 
     3.4641016151377553`}, {0.4082482904638629, -2.315291107597716, 
     2.886751345948129}, {-0.40824829046386313`, -2.315291107597716, 
     2.3094010767585034`}, {-1.1755041024585717`, -2.036032829963897, 
     2.886751345948129}}], 
    Polygon3DBox[{{0.2664651471144839, -1.5111989443921319`, 
     4.0414518843273814`}, {1.0337209591091925`, -1.790457222025951, 
     3.4641016151377553`}, {0.4082482904638629, -2.315291107597716, 
     2.886751345948129}, {-0.3590075215308457, -2.036032829963897, 
     3.4641016151377553`}}], 
    Polygon3DBox[{{0.4082482904638627, -0.7071067811865476, 
     4.618802153517007}, {1.1755041024585713`, -0.9863650588203665, 
     4.0414518843273814`}, {1.0337209591091925`, -1.790457222025951, 
     3.4641016151377553`}, {0.2664651471144839, -1.5111989443921319`, 
     4.0414518843273814`}}], 
    Polygon3DBox[{{-4.440892098500626*^-16, 0., 5.196152422706632}, {
     0.7672558119947082, -0.27925827763381905`, 4.618802153517007}, {
     1.1755041024585713`, -0.9863650588203665, 4.0414518843273814`}, {
     0.4082482904638627, -0.7071067811865476, 4.618802153517007}}]}, {
    Polygon3DBox[{{-1.1755041024585715`, -0.9863650588203667, 
      1.1547005383792517`}, {-0.4082482904638631, -0.7071067811865475, 
      0.5773502691896258}, {0, 0, 
      0}, {-0.7672558119947085, -0.27925827763381933`, 0.5773502691896258}}], 
    Polygon3DBox[{{-1.0337209591091925`, -1.790457222025951, 
     1.7320508075688776`}, {-0.2664651471144841, -1.5111989443921319`, 
     1.1547005383792517`}, {-0.4082482904638631, -0.7071067811865475, 
     0.5773502691896258}, {-1.1755041024585715`, -0.9863650588203667, 
     1.1547005383792517`}}], 
    Polygon3DBox[{{-0.40824829046386313`, -2.315291107597716, 
     2.3094010767585034`}, {0.35900752153084536`, -2.036032829963897, 
     1.7320508075688776`}, {-0.2664651471144841, -1.5111989443921319`, 
     1.1547005383792517`}, {-1.0337209591091925`, -1.790457222025951, 
     1.7320508075688776`}}], 
    Polygon3DBox[{{0.4082482904638629, -2.315291107597716, 
     2.886751345948129}, {1.1755041024585713`, -2.036032829963897, 
     2.3094010767585034`}, {0.35900752153084536`, -2.036032829963897, 
     1.7320508075688776`}, {-0.40824829046386313`, -2.315291107597716, 
     2.3094010767585034`}}], 
    Polygon3DBox[{{1.0337209591091925`, -1.790457222025951, 
     3.4641016151377553`}, {1.8009767711039006`, -1.5111989443921319`, 
     2.886751345948129}, {1.1755041024585713`, -2.036032829963897, 
     2.3094010767585034`}, {0.4082482904638629, -2.315291107597716, 
     2.886751345948129}}], 
    Polygon3DBox[{{1.1755041024585713`, -0.9863650588203665, 
     4.0414518843273814`}, {1.94275991445328, -0.7071067811865475, 
     3.4641016151377553`}, {1.8009767711039006`, -1.5111989443921319`, 
     2.886751345948129}, {1.0337209591091925`, -1.790457222025951, 
     3.4641016151377553`}}], 
    Polygon3DBox[{{0.7672558119947082, -0.27925827763381905`, 
     4.618802153517007}, {1.5345116239894165`, 0., 4.0414518843273814`}, {
     1.94275991445328, -0.7071067811865475, 3.4641016151377553`}, {
     1.1755041024585713`, -0.9863650588203665, 4.0414518843273814`}}], 
    Polygon3DBox[{{-2.220446049250313*^-16, 0., 5.196152422706632}, {
     0.7672558119947082, 0.27925827763381905`, 4.618802153517007}, {
     1.5345116239894165`, 0., 4.0414518843273814`}, {
     0.7672558119947082, -0.27925827763381905`, 4.618802153517007}}]}, {
    Polygon3DBox[{{-0.2664651471144841, -1.5111989443921319`, 
      1.1547005383792517`}, {0.14178314334937894`, -0.8040921632055843, 
      0.5773502691896258}, {0, 0, 
      0}, {-0.4082482904638631, -0.7071067811865475, 0.5773502691896258}}], 
    Polygon3DBox[{{0.35900752153084536`, -2.036032829963897, 
     1.7320508075688776`}, {0.7672558119947084, -1.3289260487773493`, 
     1.1547005383792517`}, {0.14178314334937894`, -0.8040921632055843, 
     0.5773502691896258}, {-0.2664651471144841, -1.5111989443921319`, 
     1.1547005383792517`}}], 
    Polygon3DBox[{{1.1755041024585713`, -2.036032829963897, 
     2.3094010767585034`}, {1.5837523929224344`, -1.3289260487773493`, 
     1.7320508075688776`}, {0.7672558119947084, -1.3289260487773493`, 
     1.1547005383792517`}, {0.35900752153084536`, -2.036032829963897, 
     1.7320508075688776`}}], 
    Polygon3DBox[{{1.8009767711039006`, -1.5111989443921319`, 
     2.886751345948129}, {2.2092250615677638`, -0.8040921632055843, 
     2.3094010767585034`}, {1.5837523929224344`, -1.3289260487773493`, 
     1.7320508075688776`}, {1.1755041024585713`, -2.036032829963897, 
     2.3094010767585034`}}], 
    Polygon3DBox[{{1.94275991445328, -0.7071067811865475, 
     3.4641016151377553`}, {2.351008204917143, 0., 2.886751345948129}, {
     2.2092250615677638`, -0.8040921632055843, 2.3094010767585034`}, {
     1.8009767711039006`, -1.5111989443921319`, 2.886751345948129}}], 
    Polygon3DBox[{{1.5345116239894165`, 0., 4.0414518843273814`}, {
     1.9427599144532797`, 0.7071067811865475, 3.4641016151377553`}, {
     2.351008204917143, 0., 2.886751345948129}, {
     1.94275991445328, -0.7071067811865475, 3.4641016151377553`}}], 
    Polygon3DBox[{{0.7672558119947082, 0.27925827763381905`, 
     4.618802153517007}, {1.175504102458571, 0.9863650588203668, 
     4.0414518843273814`}, {1.9427599144532797`, 0.7071067811865475, 
     3.4641016151377553`}, {1.5345116239894165`, 0., 4.0414518843273814`}}], 
    Polygon3DBox[{{-4.440892098500626*^-16, 0., 5.196152422706632}, {
     0.4082482904638627, 0.7071067811865476, 4.618802153517007}, {
     1.175504102458571, 0.9863650588203668, 4.0414518843273814`}, {
     0.7672558119947082, 0.27925827763381905`, 4.618802153517007}}]}, {
    Polygon3DBox[{{0.7672558119947084, -1.3289260487773493`, 
      1.1547005383792517`}, {0.6254726686453295, -0.524833885571765, 
      0.5773502691896258}, {0, 0, 0}, {
      0.14178314334937894`, -0.8040921632055843, 0.5773502691896258}}], 
    Polygon3DBox[{{1.5837523929224344`, -1.3289260487773493`, 
     1.7320508075688776`}, {1.4419692495730554`, -0.524833885571765, 
     1.1547005383792517`}, {0.6254726686453295, -0.524833885571765, 
     0.5773502691896258}, {0.7672558119947084, -1.3289260487773493`, 
     1.1547005383792517`}}], 
    Polygon3DBox[{{2.2092250615677638`, -0.8040921632055843, 
     2.3094010767585034`}, {2.067441918218385, 0., 1.7320508075688776`}, {
     1.4419692495730554`, -0.524833885571765, 1.1547005383792517`}, {
     1.5837523929224344`, -1.3289260487773493`, 1.7320508075688776`}}], 
    Polygon3DBox[{{2.351008204917143, 0., 2.886751345948129}, {
     2.2092250615677638`, 0.8040921632055843, 2.3094010767585034`}, {
     2.067441918218385, 0., 1.7320508075688776`}, {
     2.2092250615677638`, -0.8040921632055843, 2.3094010767585034`}}], 
    Polygon3DBox[{{1.9427599144532797`, 0.7071067811865475, 
     3.4641016151377553`}, {1.8009767711039009`, 1.5111989443921319`, 
     2.886751345948129}, {2.2092250615677638`, 0.8040921632055843, 
     2.3094010767585034`}, {2.351008204917143, 0., 2.886751345948129}}], 
    Polygon3DBox[{{1.175504102458571, 0.9863650588203668, 
     4.0414518843273814`}, {1.0337209591091923`, 1.7904572220259511`, 
     3.4641016151377553`}, {1.8009767711039009`, 1.5111989443921319`, 
     2.886751345948129}, {1.9427599144532797`, 0.7071067811865475, 
     3.4641016151377553`}}], 
    Polygon3DBox[{{0.4082482904638627, 0.7071067811865476, 
     4.618802153517007}, {0.2664651471144839, 1.5111989443921319`, 
     4.0414518843273814`}, {1.0337209591091923`, 1.7904572220259511`, 
     3.4641016151377553`}, {1.175504102458571, 0.9863650588203668, 
     4.0414518843273814`}}], 
    Polygon3DBox[{{0., 0., 5.196152422706632}, {-0.14178314334937925`, 
     0.8040921632055843, 4.618802153517007}, {0.2664651471144839, 
     1.5111989443921319`, 4.0414518843273814`}, {0.4082482904638627, 
     0.7071067811865476, 4.618802153517007}}]}, {
    Polygon3DBox[{{1.4419692495730554`, -0.524833885571765, 
      1.1547005383792517`}, {0.816496580927726, 0., 0.5773502691896258}, {0, 
      0, 0}, {0.6254726686453295, -0.524833885571765, 0.5773502691896258}}], 
    Polygon3DBox[{{2.067441918218385, 0., 1.7320508075688776`}, {
     1.4419692495730554`, 0.524833885571765, 1.1547005383792517`}, {
     0.816496580927726, 0., 0.5773502691896258}, {
     1.4419692495730554`, -0.524833885571765, 1.1547005383792517`}}], 
    Polygon3DBox[{{2.2092250615677638`, 0.8040921632055843, 
     2.3094010767585034`}, {1.5837523929224344`, 1.3289260487773493`, 
     1.7320508075688776`}, {1.4419692495730554`, 0.524833885571765, 
     1.1547005383792517`}, {2.067441918218385, 0., 1.7320508075688776`}}], 
    Polygon3DBox[{{1.8009767711039009`, 1.5111989443921319`, 
     2.886751345948129}, {1.1755041024585713`, 2.036032829963897, 
     2.3094010767585034`}, {1.5837523929224344`, 1.3289260487773493`, 
     1.7320508075688776`}, {2.2092250615677638`, 0.8040921632055843, 
     2.3094010767585034`}}], 
    Polygon3DBox[{{1.0337209591091923`, 1.7904572220259511`, 
     3.4641016151377553`}, {0.4082482904638629, 2.315291107597716, 
     2.886751345948129}, {1.1755041024585713`, 2.036032829963897, 
     2.3094010767585034`}, {1.8009767711039009`, 1.5111989443921319`, 
     2.886751345948129}}], 
    Polygon3DBox[{{0.2664651471144839, 1.5111989443921319`, 
     4.0414518843273814`}, {-0.3590075215308455, 2.036032829963897, 
     3.4641016151377553`}, {0.4082482904638629, 2.315291107597716, 
     2.886751345948129}, {1.0337209591091923`, 1.7904572220259511`, 
     3.4641016151377553`}}], 
    Polygon3DBox[{{-0.14178314334937925`, 0.8040921632055843, 
     4.618802153517007}, {-0.7672558119947088, 1.3289260487773493`, 
     4.0414518843273814`}, {-0.3590075215308455, 2.036032829963897, 
     3.4641016151377553`}, {0.2664651471144839, 1.5111989443921319`, 
     4.0414518843273814`}}], 
    Polygon3DBox[{{-2.220446049250313*^-16, 0., 
     5.196152422706632}, {-0.6254726686453298, 0.5248338855717649, 
     4.618802153517007}, {-0.7672558119947088, 1.3289260487773493`, 
     4.0414518843273814`}, {-0.14178314334937925`, 0.8040921632055843, 
     4.618802153517007}}]}, {
    Polygon3DBox[{{1.4419692495730554`, 0.524833885571765, 
      1.1547005383792517`}, {0.6254726686453295, 0.524833885571765, 
      0.5773502691896258}, {0, 0, 0}, {0.816496580927726, 0., 
      0.5773502691896258}}], 
    Polygon3DBox[{{1.5837523929224344`, 1.3289260487773493`, 
     1.7320508075688776`}, {0.7672558119947084, 1.3289260487773493`, 
     1.1547005383792517`}, {0.6254726686453295, 0.524833885571765, 
     0.5773502691896258}, {1.4419692495730554`, 0.524833885571765, 
     1.1547005383792517`}}], 
    Polygon3DBox[{{1.1755041024585713`, 2.036032829963897, 
     2.3094010767585034`}, {0.3590075215308453, 2.036032829963897, 
     1.7320508075688776`}, {0.7672558119947084, 1.3289260487773493`, 
     1.1547005383792517`}, {1.5837523929224344`, 1.3289260487773493`, 
     1.7320508075688776`}}], 
    Polygon3DBox[{{0.4082482904638629, 2.315291107597716, 
     2.886751345948129}, {-0.40824829046386313`, 2.315291107597716, 
     2.3094010767585034`}, {0.3590075215308453, 2.036032829963897, 
     1.7320508075688776`}, {1.1755041024585713`, 2.036032829963897, 
     2.3094010767585034`}}], 
    Polygon3DBox[{{-0.3590075215308455, 2.036032829963897, 
     3.4641016151377553`}, {-1.1755041024585717`, 2.036032829963897, 
     2.886751345948129}, {-0.40824829046386313`, 2.315291107597716, 
     2.3094010767585034`}, {0.4082482904638629, 2.315291107597716, 
     2.886751345948129}}], 
    Polygon3DBox[{{-0.7672558119947088, 1.3289260487773493`, 
     4.0414518843273814`}, {-1.5837523929224349`, 1.3289260487773493`, 
     3.4641016151377553`}, {-1.1755041024585717`, 2.036032829963897, 
     2.886751345948129}, {-0.3590075215308455, 2.036032829963897, 
     3.4641016151377553`}}], 
    Polygon3DBox[{{-0.6254726686453298, 0.5248338855717649, 
     4.618802153517007}, {-1.4419692495730556`, 0.5248338855717649, 
     4.0414518843273814`}, {-1.5837523929224349`, 1.3289260487773493`, 
     3.4641016151377553`}, {-0.7672558119947088, 1.3289260487773493`, 
     4.0414518843273814`}}], 
    Polygon3DBox[{{-2.220446049250313*^-16, 0., 
     5.196152422706632}, {-0.8164965809277263, 0., 
     4.618802153517007}, {-1.4419692495730556`, 0.5248338855717649, 
     4.0414518843273814`}, {-0.6254726686453298, 0.5248338855717649, 
     4.618802153517007}}]}},
  Boxed->False,
  ImageSize->{361.37806526310186`, 341.53407091516686`},
  ImageSizeRaw->Automatic,
  ViewPoint->{1.018160032647143, 1.2012244998879908`, 2.995064247856599},
  ViewVertical->{-0.2656236441051574, 0.8903993640733698, 
   0.3696390836343408}]], "Output",
 CellChangeTimes->{3.820494571430647*^9, 3.820495326352074*^9, 
  3.8204954906317873`*^9, 3.827248465121372*^9},
 CellLabel->"Out[29]=",ExpressionUUID->"20b64327-f6cf-4478-86b4-c00e3beb99fc"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"k", "=", "3"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "continue", " ", "for", " ", "k", " ", "cycles", " ", "to", " ", "show", 
    " ", "more", " ", "of", " ", "the", " ", "complete", " ", "polar", " ", 
    "zonohedron"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"Graphics3D", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"face", "[", 
      RowBox[{"i", ",", "j"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "n"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", 
       RowBox[{"i", "+", "1"}], ",", 
       RowBox[{"i", "+", 
        RowBox[{"k", " ", "n"}], "-", "1"}]}], "}"}]}], "]"}], ",", " ", 
   RowBox[{"Boxed", "\[Rule]", "False"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.8182471115319877`*^9, 3.818247139064336*^9}, {
   3.8182492085853677`*^9, 3.818249212876527*^9}, 3.8182492576071243`*^9, 
   3.818249355878507*^9, {3.820494578689997*^9, 3.820494586683711*^9}},
 CellLabel->"In[30]:=",ExpressionUUID->"6bdb4865-e543-4d46-a643-3268a68f3b2c"],

Cell[BoxData[
 Graphics3DBox[{{
    Polygon3DBox[{{0.7672558119947084, 1.3289260487773493`, 
      1.1547005383792517`}, {0.14178314334937894`, 0.8040921632055843, 
      0.5773502691896258}, {0, 0, 0}, {0.6254726686453295, 0.524833885571765, 
      0.5773502691896258}}], 
    Polygon3DBox[{{0.3590075215308453, 2.036032829963897, 
     1.7320508075688776`}, {-0.2664651471144841, 1.5111989443921319`, 
     1.1547005383792517`}, {0.14178314334937894`, 0.8040921632055843, 
     0.5773502691896258}, {0.7672558119947084, 1.3289260487773493`, 
     1.1547005383792517`}}], 
    Polygon3DBox[{{-0.40824829046386313`, 2.315291107597716, 
     2.3094010767585034`}, {-1.0337209591091927`, 1.7904572220259511`, 
     1.7320508075688776`}, {-0.2664651471144841, 1.5111989443921319`, 
     1.1547005383792517`}, {0.3590075215308453, 2.036032829963897, 
     1.7320508075688776`}}], 
    Polygon3DBox[{{-1.1755041024585717`, 2.036032829963897, 
     2.886751345948129}, {-1.800976771103901, 1.5111989443921319`, 
     2.3094010767585034`}, {-1.0337209591091927`, 1.7904572220259511`, 
     1.7320508075688776`}, {-0.40824829046386313`, 2.315291107597716, 
     2.3094010767585034`}}], 
    Polygon3DBox[{{-1.5837523929224349`, 1.3289260487773493`, 
     3.4641016151377553`}, {-2.209225061567764, 0.8040921632055844, 
     2.886751345948129}, {-1.800976771103901, 1.5111989443921319`, 
     2.3094010767585034`}, {-1.1755041024585717`, 2.036032829963897, 
     2.886751345948129}}], 
    Polygon3DBox[{{-1.4419692495730556`, 0.5248338855717649, 
     4.0414518843273814`}, {-2.0674419182183854`, 2.220446049250313*^-16, 
     3.4641016151377553`}, {-2.209225061567764, 0.8040921632055844, 
     2.886751345948129}, {-1.5837523929224349`, 1.3289260487773493`, 
     3.4641016151377553`}}], 
    Polygon3DBox[{{-0.8164965809277263, 0., 
     4.618802153517007}, {-1.4419692495730558`, -0.5248338855717649, 
     4.0414518843273814`}, {-2.0674419182183854`, 2.220446049250313*^-16, 
     3.4641016151377553`}, {-1.4419692495730556`, 0.5248338855717649, 
     4.0414518843273814`}}], 
    Polygon3DBox[{{-4.440892098500626*^-16, 0., 
     5.196152422706632}, {-0.6254726686453298, -0.5248338855717649, 
     4.618802153517007}, {-1.4419692495730558`, -0.5248338855717649, 
     4.0414518843273814`}, {-0.8164965809277263, 0., 4.618802153517007}}], 
    Polygon3DBox[{{0.6254726686453289, 0.5248338855717649, 
     5.773502691896258}, {-4.440892098500626*^-16, 1.1102230246251565`*^-16, 
     5.196152422706632}, {-0.6254726686453298, -0.5248338855717649, 
     4.618802153517007}, {-4.440892098500626*^-16, 0., 5.196152422706632}}], 
    Polygon3DBox[{{0.7672558119947082, 1.3289260487773493`, 
     6.350852961085884}, {0.1417831433493788, 0.8040921632055844, 
     5.773502691896258}, {-4.440892098500626*^-16, 1.1102230246251565`*^-16, 
     5.196152422706632}, {0.6254726686453289, 0.5248338855717649, 
     5.773502691896258}}], 
    Polygon3DBox[{{0.3590075215308448, 2.036032829963897, 
     6.9282032302755105`}, {-0.26646514711448455`, 1.511198944392132, 
     6.350852961085884}, {0.1417831433493788, 0.8040921632055844, 
     5.773502691896258}, {0.7672558119947082, 1.3289260487773493`, 
     6.350852961085884}}], 
    Polygon3DBox[{{-0.40824829046386335`, 2.315291107597716, 
     7.505553499465137}, {-1.0337209591091931`, 1.7904572220259514`, 
     6.9282032302755105`}, {-0.26646514711448455`, 1.511198944392132, 
     6.350852961085884}, {0.3590075215308448, 2.036032829963897, 
     6.9282032302755105`}}], 
    Polygon3DBox[{{-1.1755041024585717`, 2.036032829963897, 
     8.082903768654763}, {-1.8009767711039013`, 1.5111989443921319`, 
     7.505553499465137}, {-1.0337209591091931`, 1.7904572220259514`, 
     6.9282032302755105`}, {-0.40824829046386335`, 2.315291107597716, 
     7.505553499465137}}], 
    Polygon3DBox[{{-1.583752392922435, 1.3289260487773493`, 
     8.660254037844389}, {-2.2092250615677647`, 0.8040921632055844, 
     8.082903768654763}, {-1.8009767711039013`, 1.5111989443921319`, 
     7.505553499465137}, {-1.1755041024585717`, 2.036032829963897, 
     8.082903768654763}}], 
    Polygon3DBox[{{-1.441969249573056, 0.5248338855717649, 9.237604307034013},
      {-2.0674419182183854`, 0., 8.660254037844389}, {-2.2092250615677647`, 
     0.8040921632055844, 8.082903768654763}, {-1.583752392922435, 
     1.3289260487773493`, 8.660254037844389}}], 
    Polygon3DBox[{{-0.8164965809277267, 0., 
     9.814954576223638}, {-1.441969249573056, -0.5248338855717649, 
     9.237604307034013}, {-2.0674419182183854`, 0., 
     8.660254037844389}, {-1.441969249573056, 0.5248338855717649, 
     9.237604307034013}}], 
    Polygon3DBox[{{-8.881784197001252*^-16, 0., 
     10.392304845413264`}, {-0.6254726686453302, -0.5248338855717648, 
     9.814954576223638}, {-1.441969249573056, -0.5248338855717649, 
     9.237604307034013}, {-0.8164965809277267, 0., 9.814954576223638}}], 
    Polygon3DBox[{{0.6254726686453285, 0.524833885571765, 
     10.96965511460289}, {-8.881784197001252*^-16, 2.220446049250313*^-16, 
     10.392304845413264`}, {-0.6254726686453302, -0.5248338855717648, 
     9.814954576223638}, {-8.881784197001252*^-16, 0., 10.392304845413264`}}],
     Polygon3DBox[{{0.7672558119947077, 1.3289260487773493`, 
     11.547005383792516`}, {0.14178314334937836`, 0.8040921632055843, 
     10.96965511460289}, {-8.881784197001252*^-16, 2.220446049250313*^-16, 
     10.392304845413264`}, {0.6254726686453285, 0.524833885571765, 
     10.96965511460289}}], 
    Polygon3DBox[{{0.3590075215308448, 2.036032829963897, 
     12.124355652982143`}, {-0.26646514711448455`, 1.5111989443921319`, 
     11.547005383792516`}, {0.14178314334937836`, 0.8040921632055843, 
     10.96965511460289}, {0.7672558119947077, 1.3289260487773493`, 
     11.547005383792516`}}], 
    Polygon3DBox[{{-0.4082482904638636, 2.315291107597716, 
     12.701705922171769`}, {-1.0337209591091934`, 1.7904572220259511`, 
     12.124355652982143`}, {-0.26646514711448455`, 1.5111989443921319`, 
     11.547005383792516`}, {0.3590075215308448, 2.036032829963897, 
     12.124355652982143`}}], 
    Polygon3DBox[{{-1.1755041024585726`, 2.036032829963897, 
     13.279056191361395`}, {-1.800976771103902, 1.511198944392132, 
     12.701705922171769`}, {-1.0337209591091934`, 1.7904572220259511`, 
     12.124355652982143`}, {-0.4082482904638636, 2.315291107597716, 
     12.701705922171769`}}], 
    Polygon3DBox[{{-1.5837523929224357`, 1.3289260487773493`, 
     13.856406460551021`}, {-2.209225061567765, 0.8040921632055849, 
     13.279056191361395`}, {-1.800976771103902, 1.511198944392132, 
     12.701705922171769`}, {-1.1755041024585726`, 2.036032829963897, 
     13.279056191361395`}}], 
    Polygon3DBox[{{-1.4419692495730563`, 0.5248338855717651, 
     14.433756729740647`}, {-2.0674419182183863`, 6.661338147750939*^-16, 
     13.856406460551021`}, {-2.209225061567765, 0.8040921632055849, 
     13.279056191361395`}, {-1.5837523929224357`, 1.3289260487773493`, 
     13.856406460551021`}}], 
    Polygon3DBox[{{-0.8164965809277267, 0., 
     15.011106998930273`}, {-1.441969249573056, -0.5248338855717649, 
     14.433756729740647`}, {-2.0674419182183863`, 6.661338147750939*^-16, 
     13.856406460551021`}, {-1.4419692495730563`, 0.5248338855717651, 
     14.433756729740647`}}], 
    Polygon3DBox[{{-8.881784197001252*^-16, 0., 
     15.5884572681199}, {-0.6254726686453305, -0.5248338855717649, 
     15.011106998930273`}, {-1.441969249573056, -0.5248338855717649, 
     14.433756729740647`}, {-0.8164965809277267, 0., 
     15.011106998930273`}}]}, {
    Polygon3DBox[{{-0.2664651471144841, 1.5111989443921319`, 
      1.1547005383792517`}, {-0.4082482904638631, 0.7071067811865475, 
      0.5773502691896258}, {0, 0, 0}, {0.14178314334937894`, 
      0.8040921632055843, 0.5773502691896258}}], 
    Polygon3DBox[{{-1.0337209591091927`, 1.7904572220259511`, 
     1.7320508075688776`}, {-1.1755041024585715`, 0.9863650588203667, 
     1.1547005383792517`}, {-0.4082482904638631, 0.7071067811865475, 
     0.5773502691896258}, {-0.2664651471144841, 1.5111989443921319`, 
     1.1547005383792517`}}], 
    Polygon3DBox[{{-1.800976771103901, 1.5111989443921319`, 
     2.3094010767585034`}, {-1.94275991445328, 0.7071067811865475, 
     1.7320508075688776`}, {-1.1755041024585715`, 0.9863650588203667, 
     1.1547005383792517`}, {-1.0337209591091927`, 1.7904572220259511`, 
     1.7320508075688776`}}], 
    Polygon3DBox[{{-2.209225061567764, 0.8040921632055844, 
     2.886751345948129}, {-2.351008204917143, 0., 
     2.3094010767585034`}, {-1.94275991445328, 0.7071067811865475, 
     1.7320508075688776`}, {-1.800976771103901, 1.5111989443921319`, 
     2.3094010767585034`}}], 
    Polygon3DBox[{{-2.0674419182183854`, 2.220446049250313*^-16, 
     3.4641016151377553`}, {-2.209225061567764, -0.8040921632055844, 
     2.886751345948129}, {-2.351008204917143, 0., 
     2.3094010767585034`}, {-2.209225061567764, 0.8040921632055844, 
     2.886751345948129}}], 
    Polygon3DBox[{{-1.4419692495730558`, -0.5248338855717649, 
     4.0414518843273814`}, {-1.5837523929224346`, -1.3289260487773493`, 
     3.4641016151377553`}, {-2.209225061567764, -0.8040921632055844, 
     2.886751345948129}, {-2.0674419182183854`, 2.220446049250313*^-16, 
     3.4641016151377553`}}], 
    Polygon3DBox[{{-0.6254726686453298, -0.5248338855717649, 
     4.618802153517007}, {-0.7672558119947086, -1.3289260487773493`, 
     4.0414518843273814`}, {-1.5837523929224346`, -1.3289260487773493`, 
     3.4641016151377553`}, {-1.4419692495730558`, -0.5248338855717649, 
     4.0414518843273814`}}], 
    Polygon3DBox[{{-4.440892098500626*^-16, 1.1102230246251565`*^-16, 
     5.196152422706632}, {-0.14178314334937925`, -0.8040921632055843, 
     4.618802153517007}, {-0.7672558119947086, -1.3289260487773493`, 
     4.0414518843273814`}, {-0.6254726686453298, -0.5248338855717649, 
     4.618802153517007}}], 
    Polygon3DBox[{{0.1417831433493788, 0.8040921632055844, 
     5.773502691896258}, {-4.440892098500626*^-16, -1.1102230246251565`*^-16, 
     5.196152422706632}, {-0.14178314334937925`, -0.8040921632055843, 
     4.618802153517007}, {-4.440892098500626*^-16, 1.1102230246251565`*^-16, 
     5.196152422706632}}], 
    Polygon3DBox[{{-0.26646514711448455`, 1.511198944392132, 
     6.350852961085884}, {-0.40824829046386335`, 0.7071067811865475, 
     5.773502691896258}, {-4.440892098500626*^-16, -1.1102230246251565`*^-16, 
     5.196152422706632}, {0.1417831433493788, 0.8040921632055844, 
     5.773502691896258}}], 
    Polygon3DBox[{{-1.0337209591091931`, 1.7904572220259514`, 
     6.9282032302755105`}, {-1.1755041024585717`, 0.9863650588203665, 
     6.350852961085884}, {-0.40824829046386335`, 0.7071067811865475, 
     5.773502691896258}, {-0.26646514711448455`, 1.511198944392132, 
     6.350852961085884}}], 
    Polygon3DBox[{{-1.8009767711039013`, 1.5111989443921319`, 
     7.505553499465137}, {-1.9427599144532801`, 0.7071067811865475, 
     6.9282032302755105`}, {-1.1755041024585717`, 0.9863650588203665, 
     6.350852961085884}, {-1.0337209591091931`, 1.7904572220259514`, 
     6.9282032302755105`}}], 
    Polygon3DBox[{{-2.2092250615677647`, 0.8040921632055844, 
     8.082903768654763}, {-2.3510082049171435`, 0., 
     7.505553499465137}, {-1.9427599144532801`, 0.7071067811865475, 
     6.9282032302755105`}, {-1.8009767711039013`, 1.5111989443921319`, 
     7.505553499465137}}], 
    Polygon3DBox[{{-2.0674419182183854`, 0., 
     8.660254037844389}, {-2.209225061567764, -0.8040921632055844, 
     8.082903768654763}, {-2.3510082049171435`, 0., 
     7.505553499465137}, {-2.2092250615677647`, 0.8040921632055844, 
     8.082903768654763}}], 
    Polygon3DBox[{{-1.441969249573056, -0.5248338855717649, 
     9.237604307034013}, {-1.583752392922435, -1.3289260487773493`, 
     8.660254037844389}, {-2.209225061567764, -0.8040921632055844, 
     8.082903768654763}, {-2.0674419182183854`, 0., 8.660254037844389}}], 
    Polygon3DBox[{{-0.6254726686453302, -0.5248338855717648, 
     9.814954576223638}, {-0.767255811994709, -1.3289260487773493`, 
     9.237604307034013}, {-1.583752392922435, -1.3289260487773493`, 
     8.660254037844389}, {-1.441969249573056, -0.5248338855717649, 
     9.237604307034013}}], 
    Polygon3DBox[{{-8.881784197001252*^-16, 2.220446049250313*^-16, 
     10.392304845413264`}, {-0.1417831433493797, -0.8040921632055844, 
     9.814954576223638}, {-0.767255811994709, -1.3289260487773493`, 
     9.237604307034013}, {-0.6254726686453302, -0.5248338855717648, 
     9.814954576223638}}], 
    Polygon3DBox[{{0.14178314334937836`, 0.8040921632055843, 
     10.96965511460289}, {-8.881784197001252*^-16, -2.220446049250313*^-16, 
     10.392304845413264`}, {-0.1417831433493797, -0.8040921632055844, 
     9.814954576223638}, {-8.881784197001252*^-16, 2.220446049250313*^-16, 
     10.392304845413264`}}], 
    Polygon3DBox[{{-0.26646514711448455`, 1.5111989443921319`, 
     11.547005383792516`}, {-0.4082482904638638, 0.7071067811865475, 
     10.96965511460289}, {-8.881784197001252*^-16, -2.220446049250313*^-16, 
     10.392304845413264`}, {0.14178314334937836`, 0.8040921632055843, 
     10.96965511460289}}], 
    Polygon3DBox[{{-1.0337209591091934`, 1.7904572220259511`, 
     12.124355652982143`}, {-1.1755041024585722`, 0.9863650588203665, 
     11.547005383792516`}, {-0.4082482904638638, 0.7071067811865475, 
     10.96965511460289}, {-0.26646514711448455`, 1.5111989443921319`, 
     11.547005383792516`}}], 
    Polygon3DBox[{{-1.800976771103902, 1.511198944392132, 
     12.701705922171769`}, {-1.9427599144532806`, 0.7071067811865475, 
     12.124355652982143`}, {-1.1755041024585722`, 0.9863650588203665, 
     11.547005383792516`}, {-1.0337209591091934`, 1.7904572220259511`, 
     12.124355652982143`}}], 
    Polygon3DBox[{{-2.209225061567765, 0.8040921632055849, 
     13.279056191361395`}, {-2.3510082049171435`, 0., 
     12.701705922171769`}, {-1.9427599144532806`, 0.7071067811865475, 
     12.124355652982143`}, {-1.800976771103902, 1.511198944392132, 
     12.701705922171769`}}], 
    Polygon3DBox[{{-2.0674419182183863`, 6.661338147750939*^-16, 
     13.856406460551021`}, {-2.209225061567764, -0.8040921632055844, 
     13.279056191361395`}, {-2.3510082049171435`, 0., 
     12.701705922171769`}, {-2.209225061567765, 0.8040921632055849, 
     13.279056191361395`}}], 
    Polygon3DBox[{{-1.441969249573056, -0.5248338855717649, 
     14.433756729740647`}, {-1.5837523929224349`, -1.3289260487773493`, 
     13.856406460551021`}, {-2.209225061567764, -0.8040921632055844, 
     13.279056191361395`}, {-2.0674419182183863`, 6.661338147750939*^-16, 
     13.856406460551021`}}], 
    Polygon3DBox[{{-0.6254726686453305, -0.5248338855717649, 
     15.011106998930273`}, {-0.7672558119947095, -1.3289260487773493`, 
     14.433756729740647`}, {-1.5837523929224349`, -1.3289260487773493`, 
     13.856406460551021`}, {-1.441969249573056, -0.5248338855717649, 
     14.433756729740647`}}], 
    Polygon3DBox[{{-1.3322676295501878`*^-15, 3.3306690738754696`*^-16, 
     15.5884572681199}, {-0.14178314334938014`, -0.8040921632055841, 
     15.011106998930273`}, {-0.7672558119947095, -1.3289260487773493`, 
     14.433756729740647`}, {-0.6254726686453305, -0.5248338855717649, 
     15.011106998930273`}}]}, {
    Polygon3DBox[{{-1.1755041024585715`, 0.9863650588203667, 
      1.1547005383792517`}, {-0.7672558119947085, 0.27925827763381933`, 
      0.5773502691896258}, {0, 0, 0}, {-0.4082482904638631, 
      0.7071067811865475, 0.5773502691896258}}], 
    Polygon3DBox[{{-1.94275991445328, 0.7071067811865475, 
     1.7320508075688776`}, {-1.534511623989417, 0., 
     1.1547005383792517`}, {-0.7672558119947085, 0.27925827763381933`, 
     0.5773502691896258}, {-1.1755041024585715`, 0.9863650588203667, 
     1.1547005383792517`}}], 
    Polygon3DBox[{{-2.351008204917143, 0., 
     2.3094010767585034`}, {-1.9427599144532801`, -0.7071067811865475, 
     1.7320508075688776`}, {-1.534511623989417, 0., 
     1.1547005383792517`}, {-1.94275991445328, 0.7071067811865475, 
     1.7320508075688776`}}], 
    Polygon3DBox[{{-2.209225061567764, -0.8040921632055844, 
     2.886751345948129}, {-1.800976771103901, -1.5111989443921319`, 
     2.3094010767585034`}, {-1.9427599144532801`, -0.7071067811865475, 
     1.7320508075688776`}, {-2.351008204917143, 0., 2.3094010767585034`}}], 
    Polygon3DBox[{{-1.5837523929224346`, -1.3289260487773493`, 
     3.4641016151377553`}, {-1.1755041024585717`, -2.036032829963897, 
     2.886751345948129}, {-1.800976771103901, -1.5111989443921319`, 
     2.3094010767585034`}, {-2.209225061567764, -0.8040921632055844, 
     2.886751345948129}}], 
    Polygon3DBox[{{-0.7672558119947086, -1.3289260487773493`, 
     4.0414518843273814`}, {-0.3590075215308457, -2.036032829963897, 
     3.4641016151377553`}, {-1.1755041024585717`, -2.036032829963897, 
     2.886751345948129}, {-1.5837523929224346`, -1.3289260487773493`, 
     3.4641016151377553`}}], 
    Polygon3DBox[{{-0.14178314334937925`, -0.8040921632055843, 
     4.618802153517007}, {0.2664651471144839, -1.5111989443921319`, 
     4.0414518843273814`}, {-0.3590075215308457, -2.036032829963897, 
     3.4641016151377553`}, {-0.7672558119947086, -1.3289260487773493`, 
     4.0414518843273814`}}], 
    Polygon3DBox[{{-4.440892098500626*^-16, -1.1102230246251565`*^-16, 
     5.196152422706632}, {0.4082482904638627, -0.7071067811865476, 
     4.618802153517007}, {0.2664651471144839, -1.5111989443921319`, 
     4.0414518843273814`}, {-0.14178314334937925`, -0.8040921632055843, 
     4.618802153517007}}], 
    Polygon3DBox[{{-0.40824829046386335`, 0.7071067811865475, 
     5.773502691896258}, {-4.440892098500626*^-16, 0., 5.196152422706632}, {
     0.4082482904638627, -0.7071067811865476, 
     4.618802153517007}, {-4.440892098500626*^-16, -1.1102230246251565`*^-16, 
     5.196152422706632}}], 
    Polygon3DBox[{{-1.1755041024585717`, 0.9863650588203665, 
     6.350852961085884}, {-0.7672558119947088, 0.27925827763381905`, 
     5.773502691896258}, {-4.440892098500626*^-16, 0., 
     5.196152422706632}, {-0.40824829046386335`, 0.7071067811865475, 
     5.773502691896258}}], 
    Polygon3DBox[{{-1.9427599144532801`, 0.7071067811865475, 
     6.9282032302755105`}, {-1.5345116239894174`, 0., 
     6.350852961085884}, {-0.7672558119947088, 0.27925827763381905`, 
     5.773502691896258}, {-1.1755041024585717`, 0.9863650588203665, 
     6.350852961085884}}], 
    Polygon3DBox[{{-2.3510082049171435`, 0., 
     7.505553499465137}, {-1.9427599144532806`, -0.7071067811865475, 
     6.9282032302755105`}, {-1.5345116239894174`, 0., 
     6.350852961085884}, {-1.9427599144532801`, 0.7071067811865475, 
     6.9282032302755105`}}], 
    Polygon3DBox[{{-2.209225061567764, -0.8040921632055844, 
     8.082903768654763}, {-1.8009767711039015`, -1.5111989443921316`, 
     7.505553499465137}, {-1.9427599144532806`, -0.7071067811865475, 
     6.9282032302755105`}, {-2.3510082049171435`, 0., 7.505553499465137}}], 
    Polygon3DBox[{{-1.583752392922435, -1.3289260487773493`, 
     8.660254037844389}, {-1.175504102458572, -2.036032829963897, 
     8.082903768654763}, {-1.8009767711039015`, -1.5111989443921316`, 
     7.505553499465137}, {-2.209225061567764, -0.8040921632055844, 
     8.082903768654763}}], 
    Polygon3DBox[{{-0.767255811994709, -1.3289260487773493`, 
     9.237604307034013}, {-0.3590075215308459, -2.036032829963897, 
     8.660254037844389}, {-1.175504102458572, -2.036032829963897, 
     8.082903768654763}, {-1.583752392922435, -1.3289260487773493`, 
     8.660254037844389}}], 
    Polygon3DBox[{{-0.1417831433493797, -0.8040921632055844, 
     9.814954576223638}, {0.26646514711448344`, -1.5111989443921319`, 
     9.237604307034013}, {-0.3590075215308459, -2.036032829963897, 
     8.660254037844389}, {-0.767255811994709, -1.3289260487773493`, 
     9.237604307034013}}], 
    Polygon3DBox[{{-8.881784197001252*^-16, -2.220446049250313*^-16, 
     10.392304845413264`}, {0.40824829046386224`, -0.7071067811865476, 
     9.814954576223638}, {0.26646514711448344`, -1.5111989443921319`, 
     9.237604307034013}, {-0.1417831433493797, -0.8040921632055844, 
     9.814954576223638}}], 
    Polygon3DBox[{{-0.4082482904638638, 0.7071067811865475, 
     10.96965511460289}, {-8.881784197001252*^-16, 0., 10.392304845413264`}, {
     0.40824829046386224`, -0.7071067811865476, 
     9.814954576223638}, {-8.881784197001252*^-16, -2.220446049250313*^-16, 
     10.392304845413264`}}], 
    Polygon3DBox[{{-1.1755041024585722`, 0.9863650588203665, 
     11.547005383792516`}, {-0.767255811994709, 0.27925827763381905`, 
     10.96965511460289}, {-8.881784197001252*^-16, 0., 
     10.392304845413264`}, {-0.4082482904638638, 0.7071067811865475, 
     10.96965511460289}}], 
    Polygon3DBox[{{-1.9427599144532806`, 0.7071067811865475, 
     12.124355652982143`}, {-1.5345116239894177`, 0., 
     11.547005383792516`}, {-0.767255811994709, 0.27925827763381905`, 
     10.96965511460289}, {-1.1755041024585722`, 0.9863650588203665, 
     11.547005383792516`}}], 
    Polygon3DBox[{{-2.3510082049171435`, 0., 
     12.701705922171769`}, {-1.942759914453281, -0.7071067811865475, 
     12.124355652982143`}, {-1.5345116239894177`, 0., 
     11.547005383792516`}, {-1.9427599144532806`, 0.7071067811865475, 
     12.124355652982143`}}], 
    Polygon3DBox[{{-2.209225061567764, -0.8040921632055844, 
     13.279056191361395`}, {-1.8009767711039018`, -1.5111989443921319`, 
     12.701705922171769`}, {-1.942759914453281, -0.7071067811865475, 
     12.124355652982143`}, {-2.3510082049171435`, 0., 12.701705922171769`}}], 
    Polygon3DBox[{{-1.5837523929224349`, -1.3289260487773493`, 
     13.856406460551021`}, {-1.1755041024585726`, -2.036032829963897, 
     13.279056191361395`}, {-1.8009767711039018`, -1.5111989443921319`, 
     12.701705922171769`}, {-2.209225061567764, -0.8040921632055844, 
     13.279056191361395`}}], 
    Polygon3DBox[{{-0.7672558119947095, -1.3289260487773493`, 
     14.433756729740647`}, {-0.3590075215308466, -2.036032829963897, 
     13.856406460551021`}, {-1.1755041024585726`, -2.036032829963897, 
     13.279056191361395`}, {-1.5837523929224349`, -1.3289260487773493`, 
     13.856406460551021`}}], 
    Polygon3DBox[{{-0.14178314334938014`, -0.8040921632055841, 
     15.011106998930273`}, {0.266465147114483, -1.5111989443921314`, 
     14.433756729740647`}, {-0.3590075215308466, -2.036032829963897, 
     13.856406460551021`}, {-0.7672558119947095, -1.3289260487773493`, 
     14.433756729740647`}}], 
    Polygon3DBox[{{-4.440892098500626*^-16, 0., 15.5884572681199}, {
     0.40824829046386224`, -0.7071067811865472, 15.011106998930273`}, {
     0.266465147114483, -1.5111989443921314`, 
     14.433756729740647`}, {-0.14178314334938014`, -0.8040921632055841, 
     15.011106998930273`}}]}, {
    Polygon3DBox[{{-1.534511623989417, 0., 
      1.1547005383792517`}, {-0.7672558119947085, -0.27925827763381933`, 
      0.5773502691896258}, {0, 0, 0}, {-0.7672558119947085, 
      0.27925827763381933`, 0.5773502691896258}}], 
    Polygon3DBox[{{-1.9427599144532801`, -0.7071067811865475, 
     1.7320508075688776`}, {-1.1755041024585715`, -0.9863650588203667, 
     1.1547005383792517`}, {-0.7672558119947085, -0.27925827763381933`, 
     0.5773502691896258}, {-1.534511623989417, 0., 1.1547005383792517`}}], 
    Polygon3DBox[{{-1.800976771103901, -1.5111989443921319`, 
     2.3094010767585034`}, {-1.0337209591091925`, -1.790457222025951, 
     1.7320508075688776`}, {-1.1755041024585715`, -0.9863650588203667, 
     1.1547005383792517`}, {-1.9427599144532801`, -0.7071067811865475, 
     1.7320508075688776`}}], 
    Polygon3DBox[{{-1.1755041024585717`, -2.036032829963897, 
     2.886751345948129}, {-0.40824829046386313`, -2.315291107597716, 
     2.3094010767585034`}, {-1.0337209591091925`, -1.790457222025951, 
     1.7320508075688776`}, {-1.800976771103901, -1.5111989443921319`, 
     2.3094010767585034`}}], 
    Polygon3DBox[{{-0.3590075215308457, -2.036032829963897, 
     3.4641016151377553`}, {0.4082482904638629, -2.315291107597716, 
     2.886751345948129}, {-0.40824829046386313`, -2.315291107597716, 
     2.3094010767585034`}, {-1.1755041024585717`, -2.036032829963897, 
     2.886751345948129}}], 
    Polygon3DBox[{{0.2664651471144839, -1.5111989443921319`, 
     4.0414518843273814`}, {1.0337209591091925`, -1.790457222025951, 
     3.4641016151377553`}, {0.4082482904638629, -2.315291107597716, 
     2.886751345948129}, {-0.3590075215308457, -2.036032829963897, 
     3.4641016151377553`}}], 
    Polygon3DBox[{{0.4082482904638627, -0.7071067811865476, 
     4.618802153517007}, {1.1755041024585713`, -0.9863650588203665, 
     4.0414518843273814`}, {1.0337209591091925`, -1.790457222025951, 
     3.4641016151377553`}, {0.2664651471144839, -1.5111989443921319`, 
     4.0414518843273814`}}], 
    Polygon3DBox[{{-4.440892098500626*^-16, 0., 5.196152422706632}, {
     0.7672558119947082, -0.27925827763381905`, 4.618802153517007}, {
     1.1755041024585713`, -0.9863650588203665, 4.0414518843273814`}, {
     0.4082482904638627, -0.7071067811865476, 4.618802153517007}}], 
    Polygon3DBox[{{-0.7672558119947088, 0.27925827763381905`, 
     5.773502691896258}, {-2.220446049250313*^-16, 0., 5.196152422706632}, {
     0.7672558119947082, -0.27925827763381905`, 
     4.618802153517007}, {-4.440892098500626*^-16, 0., 5.196152422706632}}], 
    Polygon3DBox[{{-1.5345116239894174`, 0., 
     6.350852961085884}, {-0.7672558119947088, -0.27925827763381905`, 
     5.773502691896258}, {-2.220446049250313*^-16, 0., 
     5.196152422706632}, {-0.7672558119947088, 0.27925827763381905`, 
     5.773502691896258}}], 
    Polygon3DBox[{{-1.9427599144532806`, -0.7071067811865475, 
     6.9282032302755105`}, {-1.1755041024585717`, -0.9863650588203665, 
     6.350852961085884}, {-0.7672558119947088, -0.27925827763381905`, 
     5.773502691896258}, {-1.5345116239894174`, 0., 6.350852961085884}}], 
    Polygon3DBox[{{-1.8009767711039015`, -1.5111989443921316`, 
     7.505553499465137}, {-1.033720959109193, -1.7904572220259507`, 
     6.9282032302755105`}, {-1.1755041024585717`, -0.9863650588203665, 
     6.350852961085884}, {-1.9427599144532806`, -0.7071067811865475, 
     6.9282032302755105`}}], 
    Polygon3DBox[{{-1.175504102458572, -2.036032829963897, 
     8.082903768654763}, {-0.40824829046386335`, -2.315291107597716, 
     7.505553499465137}, {-1.033720959109193, -1.7904572220259507`, 
     6.9282032302755105`}, {-1.8009767711039015`, -1.5111989443921316`, 
     7.505553499465137}}], 
    Polygon3DBox[{{-0.3590075215308459, -2.036032829963897, 
     8.660254037844389}, {0.4082482904638627, -2.315291107597716, 
     8.082903768654763}, {-0.40824829046386335`, -2.315291107597716, 
     7.505553499465137}, {-1.175504102458572, -2.036032829963897, 
     8.082903768654763}}], 
    Polygon3DBox[{{0.26646514711448344`, -1.5111989443921319`, 
     9.237604307034013}, {1.033720959109192, -1.790457222025951, 
     8.660254037844389}, {0.4082482904638627, -2.315291107597716, 
     8.082903768654763}, {-0.3590075215308459, -2.036032829963897, 
     8.660254037844389}}], 
    Polygon3DBox[{{0.40824829046386224`, -0.7071067811865476, 
     9.814954576223638}, {1.1755041024585708`, -0.9863650588203666, 
     9.237604307034013}, {1.033720959109192, -1.790457222025951, 
     8.660254037844389}, {0.26646514711448344`, -1.5111989443921319`, 
     9.237604307034013}}], 
    Polygon3DBox[{{-8.881784197001252*^-16, 0., 10.392304845413264`}, {
     0.7672558119947079, -0.27925827763381905`, 9.814954576223638}, {
     1.1755041024585708`, -0.9863650588203666, 9.237604307034013}, {
     0.40824829046386224`, -0.7071067811865476, 9.814954576223638}}], 
    Polygon3DBox[{{-0.767255811994709, 0.27925827763381905`, 
     10.96965511460289}, {-4.440892098500626*^-16, 0., 10.392304845413264`}, {
     0.7672558119947079, -0.27925827763381905`, 
     9.814954576223638}, {-8.881784197001252*^-16, 0., 10.392304845413264`}}],
     Polygon3DBox[{{-1.5345116239894177`, 0., 
     11.547005383792516`}, {-0.7672558119947093, -0.27925827763381905`, 
     10.96965511460289}, {-4.440892098500626*^-16, 0., 
     10.392304845413264`}, {-0.767255811994709, 0.27925827763381905`, 
     10.96965511460289}}], 
    Polygon3DBox[{{-1.942759914453281, -0.7071067811865475, 
     12.124355652982143`}, {-1.1755041024585724`, -0.9863650588203665, 
     11.547005383792516`}, {-0.7672558119947093, -0.27925827763381905`, 
     10.96965511460289}, {-1.5345116239894177`, 0., 11.547005383792516`}}], 
    Polygon3DBox[{{-1.8009767711039018`, -1.5111989443921319`, 
     12.701705922171769`}, {-1.033720959109193, -1.790457222025951, 
     12.124355652982143`}, {-1.1755041024585724`, -0.9863650588203665, 
     11.547005383792516`}, {-1.942759914453281, -0.7071067811865475, 
     12.124355652982143`}}], 
    Polygon3DBox[{{-1.1755041024585726`, -2.036032829963897, 
     13.279056191361395`}, {-0.4082482904638638, -2.315291107597716, 
     12.701705922171769`}, {-1.033720959109193, -1.790457222025951, 
     12.124355652982143`}, {-1.8009767711039018`, -1.5111989443921319`, 
     12.701705922171769`}}], 
    Polygon3DBox[{{-0.3590075215308466, -2.036032829963897, 
     13.856406460551021`}, {0.40824829046386224`, -2.3152911075977154`, 
     13.279056191361395`}, {-0.4082482904638638, -2.315291107597716, 
     12.701705922171769`}, {-1.1755041024585726`, -2.036032829963897, 
     13.279056191361395`}}], 
    Polygon3DBox[{{0.266465147114483, -1.5111989443921314`, 
     14.433756729740647`}, {1.0337209591091916`, -1.7904572220259505`, 
     13.856406460551021`}, {0.40824829046386224`, -2.3152911075977154`, 
     13.279056191361395`}, {-0.3590075215308466, -2.036032829963897, 
     13.856406460551021`}}], 
    Polygon3DBox[{{0.40824829046386224`, -0.7071067811865472, 
     15.011106998930273`}, {1.175504102458571, -0.9863650588203665, 
     14.433756729740647`}, {1.0337209591091916`, -1.7904572220259505`, 
     13.856406460551021`}, {0.266465147114483, -1.5111989443921314`, 
     14.433756729740647`}}], 
    Polygon3DBox[{{-1.1102230246251565`*^-15, 0., 15.5884572681199}, {
     0.7672558119947075, -0.27925827763381905`, 15.011106998930273`}, {
     1.175504102458571, -0.9863650588203665, 14.433756729740647`}, {
     0.40824829046386224`, -0.7071067811865472, 15.011106998930273`}}]}, {
    Polygon3DBox[{{-1.1755041024585715`, -0.9863650588203667, 
      1.1547005383792517`}, {-0.4082482904638631, -0.7071067811865475, 
      0.5773502691896258}, {0, 0, 
      0}, {-0.7672558119947085, -0.27925827763381933`, 0.5773502691896258}}], 
    Polygon3DBox[{{-1.0337209591091925`, -1.790457222025951, 
     1.7320508075688776`}, {-0.2664651471144841, -1.5111989443921319`, 
     1.1547005383792517`}, {-0.4082482904638631, -0.7071067811865475, 
     0.5773502691896258}, {-1.1755041024585715`, -0.9863650588203667, 
     1.1547005383792517`}}], 
    Polygon3DBox[{{-0.40824829046386313`, -2.315291107597716, 
     2.3094010767585034`}, {0.35900752153084536`, -2.036032829963897, 
     1.7320508075688776`}, {-0.2664651471144841, -1.5111989443921319`, 
     1.1547005383792517`}, {-1.0337209591091925`, -1.790457222025951, 
     1.7320508075688776`}}], 
    Polygon3DBox[{{0.4082482904638629, -2.315291107597716, 
     2.886751345948129}, {1.1755041024585713`, -2.036032829963897, 
     2.3094010767585034`}, {0.35900752153084536`, -2.036032829963897, 
     1.7320508075688776`}, {-0.40824829046386313`, -2.315291107597716, 
     2.3094010767585034`}}], 
    Polygon3DBox[{{1.0337209591091925`, -1.790457222025951, 
     3.4641016151377553`}, {1.8009767711039006`, -1.5111989443921319`, 
     2.886751345948129}, {1.1755041024585713`, -2.036032829963897, 
     2.3094010767585034`}, {0.4082482904638629, -2.315291107597716, 
     2.886751345948129}}], 
    Polygon3DBox[{{1.1755041024585713`, -0.9863650588203665, 
     4.0414518843273814`}, {1.94275991445328, -0.7071067811865475, 
     3.4641016151377553`}, {1.8009767711039006`, -1.5111989443921319`, 
     2.886751345948129}, {1.0337209591091925`, -1.790457222025951, 
     3.4641016151377553`}}], 
    Polygon3DBox[{{0.7672558119947082, -0.27925827763381905`, 
     4.618802153517007}, {1.5345116239894165`, 0., 4.0414518843273814`}, {
     1.94275991445328, -0.7071067811865475, 3.4641016151377553`}, {
     1.1755041024585713`, -0.9863650588203665, 4.0414518843273814`}}], 
    Polygon3DBox[{{-2.220446049250313*^-16, 0., 5.196152422706632}, {
     0.7672558119947082, 0.27925827763381905`, 4.618802153517007}, {
     1.5345116239894165`, 0., 4.0414518843273814`}, {
     0.7672558119947082, -0.27925827763381905`, 4.618802153517007}}], 
    Polygon3DBox[{{-0.7672558119947088, -0.27925827763381905`, 
     5.773502691896258}, {-4.440892098500626*^-16, 0., 5.196152422706632}, {
     0.7672558119947082, 0.27925827763381905`, 
     4.618802153517007}, {-2.220446049250313*^-16, 0., 5.196152422706632}}], 
    Polygon3DBox[{{-1.1755041024585717`, -0.9863650588203665, 
     6.350852961085884}, {-0.4082482904638636, -0.7071067811865475, 
     5.773502691896258}, {-4.440892098500626*^-16, 0., 
     5.196152422706632}, {-0.7672558119947088, -0.27925827763381905`, 
     5.773502691896258}}], 
    Polygon3DBox[{{-1.033720959109193, -1.7904572220259507`, 
     6.9282032302755105`}, {-0.2664651471144843, -1.5111989443921319`, 
     6.350852961085884}, {-0.4082482904638636, -0.7071067811865475, 
     5.773502691896258}, {-1.1755041024585717`, -0.9863650588203665, 
     6.350852961085884}}], 
    Polygon3DBox[{{-0.40824829046386335`, -2.315291107597716, 
     7.505553499465137}, {0.35900752153084525`, -2.036032829963897, 
     6.9282032302755105`}, {-0.2664651471144843, -1.5111989443921319`, 
     6.350852961085884}, {-1.033720959109193, -1.7904572220259507`, 
     6.9282032302755105`}}], 
    Polygon3DBox[{{0.4082482904638627, -2.315291107597716, 
     8.082903768654763}, {1.1755041024585708`, -2.036032829963897, 
     7.505553499465137}, {0.35900752153084525`, -2.036032829963897, 
     6.9282032302755105`}, {-0.40824829046386335`, -2.315291107597716, 
     7.505553499465137}}], 
    Polygon3DBox[{{1.033720959109192, -1.790457222025951, 
     8.660254037844389}, {1.8009767711039004`, -1.5111989443921319`, 
     8.082903768654763}, {1.1755041024585708`, -2.036032829963897, 
     7.505553499465137}, {0.4082482904638627, -2.315291107597716, 
     8.082903768654763}}], 
    Polygon3DBox[{{1.1755041024585708`, -0.9863650588203666, 
     9.237604307034013}, {1.9427599144532794`, -0.7071067811865475, 
     8.660254037844389}, {1.8009767711039004`, -1.5111989443921319`, 
     8.082903768654763}, {1.033720959109192, -1.790457222025951, 
     8.660254037844389}}], 
    Polygon3DBox[{{0.7672558119947079, -0.27925827763381905`, 
     9.814954576223638}, {1.5345116239894163`, 0., 9.237604307034013}, {
     1.9427599144532794`, -0.7071067811865475, 8.660254037844389}, {
     1.1755041024585708`, -0.9863650588203666, 9.237604307034013}}], 
    Polygon3DBox[{{-4.440892098500626*^-16, 0., 10.392304845413264`}, {
     0.7672558119947077, 0.27925827763381905`, 9.814954576223638}, {
     1.5345116239894163`, 0., 9.237604307034013}, {
     0.7672558119947079, -0.27925827763381905`, 9.814954576223638}}], 
    Polygon3DBox[{{-0.7672558119947093, -0.27925827763381905`, 
     10.96965511460289}, {-8.881784197001252*^-16, 0., 10.392304845413264`}, {
     0.7672558119947077, 0.27925827763381905`, 
     9.814954576223638}, {-4.440892098500626*^-16, 0., 10.392304845413264`}}],
     Polygon3DBox[{{-1.1755041024585724`, -0.9863650588203665, 
     11.547005383792516`}, {-0.4082482904638636, -0.7071067811865475, 
     10.96965511460289}, {-8.881784197001252*^-16, 0., 
     10.392304845413264`}, {-0.7672558119947093, -0.27925827763381905`, 
     10.96965511460289}}], 
    Polygon3DBox[{{-1.033720959109193, -1.790457222025951, 
     12.124355652982143`}, {-0.26646514711448477`, -1.5111989443921319`, 
     11.547005383792516`}, {-0.4082482904638636, -0.7071067811865475, 
     10.96965511460289}, {-1.1755041024585724`, -0.9863650588203665, 
     11.547005383792516`}}], 
    Polygon3DBox[{{-0.4082482904638638, -2.315291107597716, 
     12.701705922171769`}, {0.3590075215308448, -2.036032829963897, 
     12.124355652982143`}, {-0.26646514711448477`, -1.5111989443921319`, 
     11.547005383792516`}, {-1.033720959109193, -1.790457222025951, 
     12.124355652982143`}}], 
    Polygon3DBox[{{0.40824829046386224`, -2.3152911075977154`, 
     13.279056191361395`}, {1.1755041024585708`, -2.0360328299638963`, 
     12.701705922171769`}, {0.3590075215308448, -2.036032829963897, 
     12.124355652982143`}, {-0.4082482904638638, -2.315291107597716, 
     12.701705922171769`}}], 
    Polygon3DBox[{{1.0337209591091916`, -1.7904572220259505`, 
     13.856406460551021`}, {1.8009767711039004`, -1.5111989443921319`, 
     13.279056191361395`}, {1.1755041024585708`, -2.0360328299638963`, 
     12.701705922171769`}, {0.40824829046386224`, -2.3152911075977154`, 
     13.279056191361395`}}], 
    Polygon3DBox[{{1.175504102458571, -0.9863650588203665, 
     14.433756729740647`}, {1.9427599144532797`, -0.7071067811865475, 
     13.856406460551021`}, {1.8009767711039004`, -1.5111989443921319`, 
     13.279056191361395`}, {1.0337209591091916`, -1.7904572220259505`, 
     13.856406460551021`}}], 
    Polygon3DBox[{{0.7672558119947075, -0.27925827763381905`, 
     15.011106998930273`}, {1.5345116239894157`, 0., 14.433756729740647`}, {
     1.9427599144532797`, -0.7071067811865475, 13.856406460551021`}, {
     1.175504102458571, -0.9863650588203665, 14.433756729740647`}}], 
    Polygon3DBox[{{-6.661338147750939*^-16, 0., 15.5884572681199}, {
     0.7672558119947075, 0.27925827763381905`, 15.011106998930273`}, {
     1.5345116239894157`, 0., 14.433756729740647`}, {
     0.7672558119947075, -0.27925827763381905`, 15.011106998930273`}}]}, {
    Polygon3DBox[{{-0.2664651471144841, -1.5111989443921319`, 
      1.1547005383792517`}, {0.14178314334937894`, -0.8040921632055843, 
      0.5773502691896258}, {0, 0, 
      0}, {-0.4082482904638631, -0.7071067811865475, 0.5773502691896258}}], 
    Polygon3DBox[{{0.35900752153084536`, -2.036032829963897, 
     1.7320508075688776`}, {0.7672558119947084, -1.3289260487773493`, 
     1.1547005383792517`}, {0.14178314334937894`, -0.8040921632055843, 
     0.5773502691896258}, {-0.2664651471144841, -1.5111989443921319`, 
     1.1547005383792517`}}], 
    Polygon3DBox[{{1.1755041024585713`, -2.036032829963897, 
     2.3094010767585034`}, {1.5837523929224344`, -1.3289260487773493`, 
     1.7320508075688776`}, {0.7672558119947084, -1.3289260487773493`, 
     1.1547005383792517`}, {0.35900752153084536`, -2.036032829963897, 
     1.7320508075688776`}}], 
    Polygon3DBox[{{1.8009767711039006`, -1.5111989443921319`, 
     2.886751345948129}, {2.2092250615677638`, -0.8040921632055843, 
     2.3094010767585034`}, {1.5837523929224344`, -1.3289260487773493`, 
     1.7320508075688776`}, {1.1755041024585713`, -2.036032829963897, 
     2.3094010767585034`}}], 
    Polygon3DBox[{{1.94275991445328, -0.7071067811865475, 
     3.4641016151377553`}, {2.351008204917143, 0., 2.886751345948129}, {
     2.2092250615677638`, -0.8040921632055843, 2.3094010767585034`}, {
     1.8009767711039006`, -1.5111989443921319`, 2.886751345948129}}], 
    Polygon3DBox[{{1.5345116239894165`, 0., 4.0414518843273814`}, {
     1.9427599144532797`, 0.7071067811865475, 3.4641016151377553`}, {
     2.351008204917143, 0., 2.886751345948129}, {
     1.94275991445328, -0.7071067811865475, 3.4641016151377553`}}], 
    Polygon3DBox[{{0.7672558119947082, 0.27925827763381905`, 
     4.618802153517007}, {1.175504102458571, 0.9863650588203668, 
     4.0414518843273814`}, {1.9427599144532797`, 0.7071067811865475, 
     3.4641016151377553`}, {1.5345116239894165`, 0., 4.0414518843273814`}}], 
    Polygon3DBox[{{-4.440892098500626*^-16, 0., 5.196152422706632}, {
     0.4082482904638627, 0.7071067811865476, 4.618802153517007}, {
     1.175504102458571, 0.9863650588203668, 4.0414518843273814`}, {
     0.7672558119947082, 0.27925827763381905`, 4.618802153517007}}], 
    Polygon3DBox[{{-0.4082482904638636, -0.7071067811865475, 
     5.773502691896258}, {0., 0., 5.196152422706632}, {0.4082482904638627, 
     0.7071067811865476, 4.618802153517007}, {-4.440892098500626*^-16, 0., 
     5.196152422706632}}], 
    Polygon3DBox[{{-0.2664651471144843, -1.5111989443921319`, 
     6.350852961085884}, {0.1417831433493788, -0.8040921632055844, 
     5.773502691896258}, {0., 0., 
     5.196152422706632}, {-0.4082482904638636, -0.7071067811865475, 
     5.773502691896258}}], 
    Polygon3DBox[{{0.35900752153084525`, -2.036032829963897, 
     6.9282032302755105`}, {0.7672558119947079, -1.3289260487773493`, 
     6.350852961085884}, {0.1417831433493788, -0.8040921632055844, 
     5.773502691896258}, {-0.2664651471144843, -1.5111989443921319`, 
     6.350852961085884}}], 
    Polygon3DBox[{{1.1755041024585708`, -2.036032829963897, 
     7.505553499465137}, {1.583752392922434, -1.3289260487773493`, 
     6.9282032302755105`}, {0.7672558119947079, -1.3289260487773493`, 
     6.350852961085884}, {0.35900752153084525`, -2.036032829963897, 
     6.9282032302755105`}}], 
    Polygon3DBox[{{1.8009767711039004`, -1.5111989443921319`, 
     8.082903768654763}, {2.2092250615677633`, -0.8040921632055841, 
     7.505553499465137}, {1.583752392922434, -1.3289260487773493`, 
     6.9282032302755105`}, {1.1755041024585708`, -2.036032829963897, 
     7.505553499465137}}], 
    Polygon3DBox[{{1.9427599144532794`, -0.7071067811865475, 
     8.660254037844389}, {2.351008204917142, 3.3306690738754696`*^-16, 
     8.082903768654763}, {2.2092250615677633`, -0.8040921632055841, 
     7.505553499465137}, {1.8009767711039004`, -1.5111989443921319`, 
     8.082903768654763}}], 
    Polygon3DBox[{{1.5345116239894163`, 0., 9.237604307034013}, {
     1.9427599144532792`, 0.7071067811865476, 8.660254037844389}, {
     2.351008204917142, 3.3306690738754696`*^-16, 8.082903768654763}, {
     1.9427599144532794`, -0.7071067811865475, 8.660254037844389}}], 
    Polygon3DBox[{{0.7672558119947077, 0.27925827763381905`, 
     9.814954576223638}, {1.1755041024585708`, 0.9863650588203666, 
     9.237604307034013}, {1.9427599144532792`, 0.7071067811865476, 
     8.660254037844389}, {1.5345116239894163`, 0., 9.237604307034013}}], 
    Polygon3DBox[{{-8.881784197001252*^-16, 0., 10.392304845413264`}, {
     0.4082482904638627, 0.7071067811865476, 9.814954576223638}, {
     1.1755041024585708`, 0.9863650588203666, 9.237604307034013}, {
     0.7672558119947077, 0.27925827763381905`, 9.814954576223638}}], 
    Polygon3DBox[{{-0.4082482904638636, -0.7071067811865475, 
     10.96965511460289}, {0., 0., 10.392304845413264`}, {0.4082482904638627, 
     0.7071067811865476, 9.814954576223638}, {-8.881784197001252*^-16, 0., 
     10.392304845413264`}}], 
    Polygon3DBox[{{-0.26646514711448477`, -1.5111989443921319`, 
     11.547005383792516`}, {0.14178314334937858`, -0.8040921632055844, 
     10.96965511460289}, {0., 0., 
     10.392304845413264`}, {-0.4082482904638636, -0.7071067811865475, 
     10.96965511460289}}], 
    Polygon3DBox[{{0.3590075215308448, -2.036032829963897, 
     12.124355652982143`}, {0.7672558119947079, -1.3289260487773493`, 
     11.547005383792516`}, {0.14178314334937858`, -0.8040921632055844, 
     10.96965511460289}, {-0.26646514711448477`, -1.5111989443921319`, 
     11.547005383792516`}}], 
    Polygon3DBox[{{1.1755041024585708`, -2.0360328299638963`, 
     12.701705922171769`}, {1.5837523929224337`, -1.3289260487773493`, 
     12.124355652982143`}, {0.7672558119947079, -1.3289260487773493`, 
     11.547005383792516`}, {0.3590075215308448, -2.036032829963897, 
     12.124355652982143`}}], 
    Polygon3DBox[{{1.8009767711039004`, -1.5111989443921319`, 
     13.279056191361395`}, {2.2092250615677633`, -0.8040921632055844, 
     12.701705922171769`}, {1.5837523929224337`, -1.3289260487773493`, 
     12.124355652982143`}, {1.1755041024585708`, -2.0360328299638963`, 
     12.701705922171769`}}], 
    Polygon3DBox[{{1.9427599144532797`, -0.7071067811865475, 
     13.856406460551021`}, {2.351008204917142, 0., 13.279056191361395`}, {
     2.2092250615677633`, -0.8040921632055844, 12.701705922171769`}, {
     1.8009767711039004`, -1.5111989443921319`, 13.279056191361395`}}], 
    Polygon3DBox[{{1.5345116239894157`, 0., 14.433756729740647`}, {
     1.9427599144532788`, 0.7071067811865475, 13.856406460551021`}, {
     2.351008204917142, 0., 13.279056191361395`}, {
     1.9427599144532797`, -0.7071067811865475, 13.856406460551021`}}], 
    Polygon3DBox[{{0.7672558119947075, 0.27925827763381905`, 
     15.011106998930273`}, {1.1755041024585702`, 0.9863650588203673, 
     14.433756729740647`}, {1.9427599144532788`, 0.7071067811865475, 
     13.856406460551021`}, {1.5345116239894157`, 0., 14.433756729740647`}}], 
    Polygon3DBox[{{-8.881784197001252*^-16, 0., 15.5884572681199}, {
     0.408248290463862, 0.7071067811865478, 15.011106998930273`}, {
     1.1755041024585702`, 0.9863650588203673, 14.433756729740647`}, {
     0.7672558119947075, 0.27925827763381905`, 15.011106998930273`}}]}, {
    Polygon3DBox[{{0.7672558119947084, -1.3289260487773493`, 
      1.1547005383792517`}, {0.6254726686453295, -0.524833885571765, 
      0.5773502691896258}, {0, 0, 0}, {
      0.14178314334937894`, -0.8040921632055843, 0.5773502691896258}}], 
    Polygon3DBox[{{1.5837523929224344`, -1.3289260487773493`, 
     1.7320508075688776`}, {1.4419692495730554`, -0.524833885571765, 
     1.1547005383792517`}, {0.6254726686453295, -0.524833885571765, 
     0.5773502691896258}, {0.7672558119947084, -1.3289260487773493`, 
     1.1547005383792517`}}], 
    Polygon3DBox[{{2.2092250615677638`, -0.8040921632055843, 
     2.3094010767585034`}, {2.067441918218385, 0., 1.7320508075688776`}, {
     1.4419692495730554`, -0.524833885571765, 1.1547005383792517`}, {
     1.5837523929224344`, -1.3289260487773493`, 1.7320508075688776`}}], 
    Polygon3DBox[{{2.351008204917143, 0., 2.886751345948129}, {
     2.2092250615677638`, 0.8040921632055843, 2.3094010767585034`}, {
     2.067441918218385, 0., 1.7320508075688776`}, {
     2.2092250615677638`, -0.8040921632055843, 2.3094010767585034`}}], 
    Polygon3DBox[{{1.9427599144532797`, 0.7071067811865475, 
     3.4641016151377553`}, {1.8009767711039009`, 1.5111989443921319`, 
     2.886751345948129}, {2.2092250615677638`, 0.8040921632055843, 
     2.3094010767585034`}, {2.351008204917143, 0., 2.886751345948129}}], 
    Polygon3DBox[{{1.175504102458571, 0.9863650588203668, 
     4.0414518843273814`}, {1.0337209591091923`, 1.7904572220259511`, 
     3.4641016151377553`}, {1.8009767711039009`, 1.5111989443921319`, 
     2.886751345948129}, {1.9427599144532797`, 0.7071067811865475, 
     3.4641016151377553`}}], 
    Polygon3DBox[{{0.4082482904638627, 0.7071067811865476, 
     4.618802153517007}, {0.2664651471144839, 1.5111989443921319`, 
     4.0414518843273814`}, {1.0337209591091923`, 1.7904572220259511`, 
     3.4641016151377553`}, {1.175504102458571, 0.9863650588203668, 
     4.0414518843273814`}}], 
    Polygon3DBox[{{0., 0., 5.196152422706632}, {-0.14178314334937925`, 
     0.8040921632055843, 4.618802153517007}, {0.2664651471144839, 
     1.5111989443921319`, 4.0414518843273814`}, {0.4082482904638627, 
     0.7071067811865476, 4.618802153517007}}], 
    Polygon3DBox[{{0.1417831433493788, -0.8040921632055844, 
     5.773502691896258}, {-2.220446049250313*^-16, 0., 
     5.196152422706632}, {-0.14178314334937925`, 0.8040921632055843, 
     4.618802153517007}, {0., 0., 5.196152422706632}}], 
    Polygon3DBox[{{0.7672558119947079, -1.3289260487773493`, 
     6.350852961085884}, {0.6254726686453291, -0.5248338855717649, 
     5.773502691896258}, {-2.220446049250313*^-16, 0., 5.196152422706632}, {
     0.1417831433493788, -0.8040921632055844, 5.773502691896258}}], 
    Polygon3DBox[{{1.583752392922434, -1.3289260487773493`, 
     6.9282032302755105`}, {1.4419692495730552`, -0.5248338855717647, 
     6.350852961085884}, {0.6254726686453291, -0.5248338855717649, 
     5.773502691896258}, {0.7672558119947079, -1.3289260487773493`, 
     6.350852961085884}}], 
    Polygon3DBox[{{2.2092250615677633`, -0.8040921632055841, 
     7.505553499465137}, {2.0674419182183845`, 2.220446049250313*^-16, 
     6.9282032302755105`}, {1.4419692495730552`, -0.5248338855717647, 
     6.350852961085884}, {1.583752392922434, -1.3289260487773493`, 
     6.9282032302755105`}}], 
    Polygon3DBox[{{2.351008204917142, 3.3306690738754696`*^-16, 
     8.082903768654763}, {2.2092250615677638`, 0.8040921632055844, 
     7.505553499465137}, {2.0674419182183845`, 2.220446049250313*^-16, 
     6.9282032302755105`}, {2.2092250615677633`, -0.8040921632055841, 
     7.505553499465137}}], 
    Polygon3DBox[{{1.9427599144532792`, 0.7071067811865476, 
     8.660254037844389}, {1.8009767711039004`, 1.5111989443921319`, 
     8.082903768654763}, {2.2092250615677638`, 0.8040921632055844, 
     7.505553499465137}, {2.351008204917142, 3.3306690738754696`*^-16, 
     8.082903768654763}}], 
    Polygon3DBox[{{1.1755041024585708`, 0.9863650588203666, 
     9.237604307034013}, {1.0337209591091918`, 1.7904572220259511`, 
     8.660254037844389}, {1.8009767711039004`, 1.5111989443921319`, 
     8.082903768654763}, {1.9427599144532792`, 0.7071067811865476, 
     8.660254037844389}}], 
    Polygon3DBox[{{0.4082482904638627, 0.7071067811865476, 
     9.814954576223638}, {0.26646514711448344`, 1.5111989443921319`, 
     9.237604307034013}, {1.0337209591091918`, 1.7904572220259511`, 
     8.660254037844389}, {1.1755041024585708`, 0.9863650588203666, 
     9.237604307034013}}], 
    Polygon3DBox[{{0., 0., 10.392304845413264`}, {-0.14178314334937947`, 
     0.8040921632055843, 9.814954576223638}, {0.26646514711448344`, 
     1.5111989443921319`, 9.237604307034013}, {0.4082482904638627, 
     0.7071067811865476, 9.814954576223638}}], 
    Polygon3DBox[{{0.14178314334937858`, -0.8040921632055844, 
     10.96965511460289}, {-4.440892098500626*^-16, 0., 
     10.392304845413264`}, {-0.14178314334937947`, 0.8040921632055843, 
     9.814954576223638}, {0., 0., 10.392304845413264`}}], 
    Polygon3DBox[{{0.7672558119947079, -1.3289260487773493`, 
     11.547005383792516`}, {0.6254726686453289, -0.5248338855717649, 
     10.96965511460289}, {-4.440892098500626*^-16, 0., 10.392304845413264`}, {
     0.14178314334937858`, -0.8040921632055844, 10.96965511460289}}], 
    Polygon3DBox[{{1.5837523929224337`, -1.3289260487773493`, 
     12.124355652982143`}, {1.441969249573055, -0.5248338855717649, 
     11.547005383792516`}, {0.6254726686453289, -0.5248338855717649, 
     10.96965511460289}, {0.7672558119947079, -1.3289260487773493`, 
     11.547005383792516`}}], 
    Polygon3DBox[{{2.2092250615677633`, -0.8040921632055844, 
     12.701705922171769`}, {2.067441918218384, 2.220446049250313*^-16, 
     12.124355652982143`}, {1.441969249573055, -0.5248338855717649, 
     11.547005383792516`}, {1.5837523929224337`, -1.3289260487773493`, 
     12.124355652982143`}}], 
    Polygon3DBox[{{2.351008204917142, 0., 13.279056191361395`}, {
     2.2092250615677633`, 0.8040921632055846, 12.701705922171769`}, {
     2.067441918218384, 2.220446049250313*^-16, 12.124355652982143`}, {
     2.2092250615677633`, -0.8040921632055844, 12.701705922171769`}}], 
    Polygon3DBox[{{1.9427599144532788`, 0.7071067811865475, 
     13.856406460551021`}, {1.8009767711039, 1.5111989443921323`, 
     13.279056191361395`}, {2.2092250615677633`, 0.8040921632055846, 
     12.701705922171769`}, {2.351008204917142, 0., 13.279056191361395`}}], 
    Polygon3DBox[{{1.1755041024585702`, 0.9863650588203673, 
     14.433756729740647`}, {1.0337209591091914`, 1.7904572220259516`, 
     13.856406460551021`}, {1.8009767711039, 1.5111989443921323`, 
     13.279056191361395`}, {1.9427599144532788`, 0.7071067811865475, 
     13.856406460551021`}}], 
    Polygon3DBox[{{0.408248290463862, 0.7071067811865478, 
     15.011106998930273`}, {0.26646514711448366`, 1.5111989443921319`, 
     14.433756729740647`}, {1.0337209591091914`, 1.7904572220259516`, 
     13.856406460551021`}, {1.1755041024585702`, 0.9863650588203673, 
     14.433756729740647`}}], 
    Polygon3DBox[{{-1.3322676295501878`*^-15, 3.3306690738754696`*^-16, 
     15.5884572681199}, {-0.1417831433493797, 0.8040921632055844, 
     15.011106998930273`}, {0.26646514711448366`, 1.5111989443921319`, 
     14.433756729740647`}, {0.408248290463862, 0.7071067811865478, 
     15.011106998930273`}}]}, {
    Polygon3DBox[{{1.4419692495730554`, -0.524833885571765, 
      1.1547005383792517`}, {0.816496580927726, 0., 0.5773502691896258}, {0, 
      0, 0}, {0.6254726686453295, -0.524833885571765, 0.5773502691896258}}], 
    Polygon3DBox[{{2.067441918218385, 0., 1.7320508075688776`}, {
     1.4419692495730554`, 0.524833885571765, 1.1547005383792517`}, {
     0.816496580927726, 0., 0.5773502691896258}, {
     1.4419692495730554`, -0.524833885571765, 1.1547005383792517`}}], 
    Polygon3DBox[{{2.2092250615677638`, 0.8040921632055843, 
     2.3094010767585034`}, {1.5837523929224344`, 1.3289260487773493`, 
     1.7320508075688776`}, {1.4419692495730554`, 0.524833885571765, 
     1.1547005383792517`}, {2.067441918218385, 0., 1.7320508075688776`}}], 
    Polygon3DBox[{{1.8009767711039009`, 1.5111989443921319`, 
     2.886751345948129}, {1.1755041024585713`, 2.036032829963897, 
     2.3094010767585034`}, {1.5837523929224344`, 1.3289260487773493`, 
     1.7320508075688776`}, {2.2092250615677638`, 0.8040921632055843, 
     2.3094010767585034`}}], 
    Polygon3DBox[{{1.0337209591091923`, 1.7904572220259511`, 
     3.4641016151377553`}, {0.4082482904638629, 2.315291107597716, 
     2.886751345948129}, {1.1755041024585713`, 2.036032829963897, 
     2.3094010767585034`}, {1.8009767711039009`, 1.5111989443921319`, 
     2.886751345948129}}], 
    Polygon3DBox[{{0.2664651471144839, 1.5111989443921319`, 
     4.0414518843273814`}, {-0.3590075215308455, 2.036032829963897, 
     3.4641016151377553`}, {0.4082482904638629, 2.315291107597716, 
     2.886751345948129}, {1.0337209591091923`, 1.7904572220259511`, 
     3.4641016151377553`}}], 
    Polygon3DBox[{{-0.14178314334937925`, 0.8040921632055843, 
     4.618802153517007}, {-0.7672558119947088, 1.3289260487773493`, 
     4.0414518843273814`}, {-0.3590075215308455, 2.036032829963897, 
     3.4641016151377553`}, {0.2664651471144839, 1.5111989443921319`, 
     4.0414518843273814`}}], 
    Polygon3DBox[{{-2.220446049250313*^-16, 0., 
     5.196152422706632}, {-0.6254726686453298, 0.5248338855717649, 
     4.618802153517007}, {-0.7672558119947088, 1.3289260487773493`, 
     4.0414518843273814`}, {-0.14178314334937925`, 0.8040921632055843, 
     4.618802153517007}}], 
    Polygon3DBox[{{0.6254726686453291, -0.5248338855717649, 
     5.773502691896258}, {-2.220446049250313*^-16, 0., 
     5.196152422706632}, {-0.6254726686453298, 0.5248338855717649, 
     4.618802153517007}, {-2.220446049250313*^-16, 0., 5.196152422706632}}], 
    Polygon3DBox[{{1.4419692495730552`, -0.5248338855717647, 
     6.350852961085884}, {0.8164965809277258, 0., 
     5.773502691896258}, {-2.220446049250313*^-16, 0., 5.196152422706632}, {
     0.6254726686453291, -0.5248338855717649, 5.773502691896258}}], 
    Polygon3DBox[{{2.0674419182183845`, 2.220446049250313*^-16, 
     6.9282032302755105`}, {1.4419692495730552`, 0.5248338855717649, 
     6.350852961085884}, {0.8164965809277258, 0., 5.773502691896258}, {
     1.4419692495730552`, -0.5248338855717647, 6.350852961085884}}], 
    Polygon3DBox[{{2.2092250615677638`, 0.8040921632055844, 
     7.505553499465137}, {1.5837523929224344`, 1.3289260487773493`, 
     6.9282032302755105`}, {1.4419692495730552`, 0.5248338855717649, 
     6.350852961085884}, {2.0674419182183845`, 2.220446049250313*^-16, 
     6.9282032302755105`}}], 
    Polygon3DBox[{{1.8009767711039004`, 1.5111989443921319`, 
     8.082903768654763}, {1.1755041024585708`, 2.036032829963897, 
     7.505553499465137}, {1.5837523929224344`, 1.3289260487773493`, 
     6.9282032302755105`}, {2.2092250615677638`, 0.8040921632055844, 
     7.505553499465137}}], 
    Polygon3DBox[{{1.0337209591091918`, 1.7904572220259511`, 
     8.660254037844389}, {0.40824829046386224`, 2.3152911075977163`, 
     8.082903768654763}, {1.1755041024585708`, 2.036032829963897, 
     7.505553499465137}, {1.8009767711039004`, 1.5111989443921319`, 
     8.082903768654763}}], 
    Polygon3DBox[{{0.26646514711448344`, 1.5111989443921319`, 
     9.237604307034013}, {-0.3590075215308459, 2.036032829963897, 
     8.660254037844389}, {0.40824829046386224`, 2.3152911075977163`, 
     8.082903768654763}, {1.0337209591091918`, 1.7904572220259511`, 
     8.660254037844389}}], 
    Polygon3DBox[{{-0.14178314334937947`, 0.8040921632055843, 
     9.814954576223638}, {-0.767255811994709, 1.3289260487773493`, 
     9.237604307034013}, {-0.3590075215308459, 2.036032829963897, 
     8.660254037844389}, {0.26646514711448344`, 1.5111989443921319`, 
     9.237604307034013}}], 
    Polygon3DBox[{{-4.440892098500626*^-16, 0., 
     10.392304845413264`}, {-0.62547266864533, 0.5248338855717649, 
     9.814954576223638}, {-0.767255811994709, 1.3289260487773493`, 
     9.237604307034013}, {-0.14178314334937947`, 0.8040921632055843, 
     9.814954576223638}}], 
    Polygon3DBox[{{0.6254726686453289, -0.5248338855717649, 
     10.96965511460289}, {-4.440892098500626*^-16, 0., 
     10.392304845413264`}, {-0.62547266864533, 0.5248338855717649, 
     9.814954576223638}, {-4.440892098500626*^-16, 0., 10.392304845413264`}}],
     Polygon3DBox[{{1.441969249573055, -0.5248338855717649, 
     11.547005383792516`}, {0.8164965809277254, 0., 
     10.96965511460289}, {-4.440892098500626*^-16, 0., 10.392304845413264`}, {
     0.6254726686453289, -0.5248338855717649, 10.96965511460289}}], 
    Polygon3DBox[{{2.067441918218384, 2.220446049250313*^-16, 
     12.124355652982143`}, {1.4419692495730547`, 0.5248338855717649, 
     11.547005383792516`}, {0.8164965809277254, 0., 10.96965511460289}, {
     1.441969249573055, -0.5248338855717649, 11.547005383792516`}}], 
    Polygon3DBox[{{2.2092250615677633`, 0.8040921632055846, 
     12.701705922171769`}, {1.583752392922434, 1.3289260487773493`, 
     12.124355652982143`}, {1.4419692495730547`, 0.5248338855717649, 
     11.547005383792516`}, {2.067441918218384, 2.220446049250313*^-16, 
     12.124355652982143`}}], 
    Polygon3DBox[{{1.8009767711039, 1.5111989443921323`, 
     13.279056191361395`}, {1.1755041024585706`, 2.0360328299638972`, 
     12.701705922171769`}, {1.583752392922434, 1.3289260487773493`, 
     12.124355652982143`}, {2.2092250615677633`, 0.8040921632055846, 
     12.701705922171769`}}], 
    Polygon3DBox[{{1.0337209591091914`, 1.7904572220259516`, 
     13.856406460551021`}, {0.4082482904638627, 2.315291107597716, 
     13.279056191361395`}, {1.1755041024585706`, 2.0360328299638972`, 
     12.701705922171769`}, {1.8009767711039, 1.5111989443921323`, 
     13.279056191361395`}}], 
    Polygon3DBox[{{0.26646514711448366`, 1.5111989443921319`, 
     14.433756729740647`}, {-0.3590075215308457, 2.036032829963897, 
     13.856406460551021`}, {0.4082482904638627, 2.315291107597716, 
     13.279056191361395`}, {1.0337209591091914`, 1.7904572220259516`, 
     13.856406460551021`}}], 
    Polygon3DBox[{{-0.1417831433493797, 0.8040921632055844, 
     15.011106998930273`}, {-0.7672558119947097, 1.3289260487773493`, 
     14.433756729740647`}, {-0.3590075215308457, 2.036032829963897, 
     13.856406460551021`}, {0.26646514711448366`, 1.5111989443921319`, 
     14.433756729740647`}}], 
    Polygon3DBox[{{-1.1102230246251565`*^-15, 2.220446049250313*^-16, 
     15.5884572681199}, {-0.6254726686453307, 0.5248338855717651, 
     15.011106998930273`}, {-0.7672558119947097, 1.3289260487773493`, 
     14.433756729740647`}, {-0.1417831433493797, 0.8040921632055844, 
     15.011106998930273`}}]}, {
    Polygon3DBox[{{1.4419692495730554`, 0.524833885571765, 
      1.1547005383792517`}, {0.6254726686453295, 0.524833885571765, 
      0.5773502691896258}, {0, 0, 0}, {0.816496580927726, 0., 
      0.5773502691896258}}], 
    Polygon3DBox[{{1.5837523929224344`, 1.3289260487773493`, 
     1.7320508075688776`}, {0.7672558119947084, 1.3289260487773493`, 
     1.1547005383792517`}, {0.6254726686453295, 0.524833885571765, 
     0.5773502691896258}, {1.4419692495730554`, 0.524833885571765, 
     1.1547005383792517`}}], 
    Polygon3DBox[{{1.1755041024585713`, 2.036032829963897, 
     2.3094010767585034`}, {0.3590075215308453, 2.036032829963897, 
     1.7320508075688776`}, {0.7672558119947084, 1.3289260487773493`, 
     1.1547005383792517`}, {1.5837523929224344`, 1.3289260487773493`, 
     1.7320508075688776`}}], 
    Polygon3DBox[{{0.4082482904638629, 2.315291107597716, 
     2.886751345948129}, {-0.40824829046386313`, 2.315291107597716, 
     2.3094010767585034`}, {0.3590075215308453, 2.036032829963897, 
     1.7320508075688776`}, {1.1755041024585713`, 2.036032829963897, 
     2.3094010767585034`}}], 
    Polygon3DBox[{{-0.3590075215308455, 2.036032829963897, 
     3.4641016151377553`}, {-1.1755041024585717`, 2.036032829963897, 
     2.886751345948129}, {-0.40824829046386313`, 2.315291107597716, 
     2.3094010767585034`}, {0.4082482904638629, 2.315291107597716, 
     2.886751345948129}}], 
    Polygon3DBox[{{-0.7672558119947088, 1.3289260487773493`, 
     4.0414518843273814`}, {-1.5837523929224349`, 1.3289260487773493`, 
     3.4641016151377553`}, {-1.1755041024585717`, 2.036032829963897, 
     2.886751345948129}, {-0.3590075215308455, 2.036032829963897, 
     3.4641016151377553`}}], 
    Polygon3DBox[{{-0.6254726686453298, 0.5248338855717649, 
     4.618802153517007}, {-1.4419692495730556`, 0.5248338855717649, 
     4.0414518843273814`}, {-1.5837523929224349`, 1.3289260487773493`, 
     3.4641016151377553`}, {-0.7672558119947088, 1.3289260487773493`, 
     4.0414518843273814`}}], 
    Polygon3DBox[{{-2.220446049250313*^-16, 0., 
     5.196152422706632}, {-0.8164965809277263, 0., 
     4.618802153517007}, {-1.4419692495730556`, 0.5248338855717649, 
     4.0414518843273814`}, {-0.6254726686453298, 0.5248338855717649, 
     4.618802153517007}}], 
    Polygon3DBox[{{0.8164965809277258, 0., 
     5.773502691896258}, {-4.440892098500626*^-16, 0., 
     5.196152422706632}, {-0.8164965809277263, 0., 
     4.618802153517007}, {-2.220446049250313*^-16, 0., 5.196152422706632}}], 
    Polygon3DBox[{{1.4419692495730552`, 0.5248338855717649, 
     6.350852961085884}, {0.6254726686453289, 0.5248338855717649, 
     5.773502691896258}, {-4.440892098500626*^-16, 0., 5.196152422706632}, {
     0.8164965809277258, 0., 5.773502691896258}}], 
    Polygon3DBox[{{1.5837523929224344`, 1.3289260487773493`, 
     6.9282032302755105`}, {0.7672558119947082, 1.3289260487773493`, 
     6.350852961085884}, {0.6254726686453289, 0.5248338855717649, 
     5.773502691896258}, {1.4419692495730552`, 0.5248338855717649, 
     6.350852961085884}}], 
    Polygon3DBox[{{1.1755041024585708`, 2.036032829963897, 
     7.505553499465137}, {0.3590075215308448, 2.036032829963897, 
     6.9282032302755105`}, {0.7672558119947082, 1.3289260487773493`, 
     6.350852961085884}, {1.5837523929224344`, 1.3289260487773493`, 
     6.9282032302755105`}}], 
    Polygon3DBox[{{0.40824829046386224`, 2.3152911075977163`, 
     8.082903768654763}, {-0.40824829046386335`, 2.315291107597716, 
     7.505553499465137}, {0.3590075215308448, 2.036032829963897, 
     6.9282032302755105`}, {1.1755041024585708`, 2.036032829963897, 
     7.505553499465137}}], 
    Polygon3DBox[{{-0.3590075215308459, 2.036032829963897, 
     8.660254037844389}, {-1.1755041024585717`, 2.036032829963897, 
     8.082903768654763}, {-0.40824829046386335`, 2.315291107597716, 
     7.505553499465137}, {0.40824829046386224`, 2.3152911075977163`, 
     8.082903768654763}}], 
    Polygon3DBox[{{-0.767255811994709, 1.3289260487773493`, 
     9.237604307034013}, {-1.583752392922435, 1.3289260487773493`, 
     8.660254037844389}, {-1.1755041024585717`, 2.036032829963897, 
     8.082903768654763}, {-0.3590075215308459, 2.036032829963897, 
     8.660254037844389}}], 
    Polygon3DBox[{{-0.62547266864533, 0.5248338855717649, 
     9.814954576223638}, {-1.441969249573056, 0.5248338855717649, 
     9.237604307034013}, {-1.583752392922435, 1.3289260487773493`, 
     8.660254037844389}, {-0.767255811994709, 1.3289260487773493`, 
     9.237604307034013}}], 
    Polygon3DBox[{{-4.440892098500626*^-16, 0., 
     10.392304845413264`}, {-0.8164965809277267, 0., 
     9.814954576223638}, {-1.441969249573056, 0.5248338855717649, 
     9.237604307034013}, {-0.62547266864533, 0.5248338855717649, 
     9.814954576223638}}], 
    Polygon3DBox[{{0.8164965809277254, 0., 
     10.96965511460289}, {-8.881784197001252*^-16, 0., 
     10.392304845413264`}, {-0.8164965809277267, 0., 
     9.814954576223638}, {-4.440892098500626*^-16, 0., 10.392304845413264`}}],
     Polygon3DBox[{{1.4419692495730547`, 0.5248338855717649, 
     11.547005383792516`}, {0.6254726686453285, 0.524833885571765, 
     10.96965511460289}, {-8.881784197001252*^-16, 0., 10.392304845413264`}, {
     0.8164965809277254, 0., 10.96965511460289}}], 
    Polygon3DBox[{{1.583752392922434, 1.3289260487773493`, 
     12.124355652982143`}, {0.7672558119947077, 1.3289260487773493`, 
     11.547005383792516`}, {0.6254726686453285, 0.524833885571765, 
     10.96965511460289}, {1.4419692495730547`, 0.5248338855717649, 
     11.547005383792516`}}], 
    Polygon3DBox[{{1.1755041024585706`, 2.0360328299638972`, 
     12.701705922171769`}, {0.3590075215308448, 2.036032829963897, 
     12.124355652982143`}, {0.7672558119947077, 1.3289260487773493`, 
     11.547005383792516`}, {1.583752392922434, 1.3289260487773493`, 
     12.124355652982143`}}], 
    Polygon3DBox[{{0.4082482904638627, 2.315291107597716, 
     13.279056191361395`}, {-0.4082482904638636, 2.315291107597716, 
     12.701705922171769`}, {0.3590075215308448, 2.036032829963897, 
     12.124355652982143`}, {1.1755041024585706`, 2.0360328299638972`, 
     12.701705922171769`}}], 
    Polygon3DBox[{{-0.3590075215308457, 2.036032829963897, 
     13.856406460551021`}, {-1.1755041024585726`, 2.036032829963897, 
     13.279056191361395`}, {-0.4082482904638636, 2.315291107597716, 
     12.701705922171769`}, {0.4082482904638627, 2.315291107597716, 
     13.279056191361395`}}], 
    Polygon3DBox[{{-0.7672558119947097, 1.3289260487773493`, 
     14.433756729740647`}, {-1.5837523929224357`, 1.3289260487773493`, 
     13.856406460551021`}, {-1.1755041024585726`, 2.036032829963897, 
     13.279056191361395`}, {-0.3590075215308457, 2.036032829963897, 
     13.856406460551021`}}], 
    Polygon3DBox[{{-0.6254726686453307, 0.5248338855717651, 
     15.011106998930273`}, {-1.4419692495730563`, 0.5248338855717651, 
     14.433756729740647`}, {-1.5837523929224357`, 1.3289260487773493`, 
     13.856406460551021`}, {-0.7672558119947097, 1.3289260487773493`, 
     14.433756729740647`}}], 
    Polygon3DBox[{{-1.1102230246251565`*^-15, 4.440892098500626*^-16, 
     15.5884572681199}, {-0.8164965809277267, 0., 
     15.011106998930273`}, {-1.4419692495730563`, 0.5248338855717651, 
     14.433756729740647`}, {-0.6254726686453307, 0.5248338855717651, 
     15.011106998930273`}}]}},
  Boxed->False,
  ImageSize->{365.45453753353166`, 108.33464446890108`},
  ViewPoint->{1.1264870355407315`, -3.186373608957745, -0.16748188826335278`},
  ViewVertical->{-1.8702430039062365`, -2.8299786046841917`, \
-0.00953455400885149}]], "Output",
 CellChangeTimes->{
  3.818247143114197*^9, {3.818249209386153*^9, 3.8182492186558223`*^9}, 
   3.818249261413313*^9, 3.8182493574503984`*^9, 3.8183313404613657`*^9, 
   3.820494594720696*^9, 3.8204953542079268`*^9, 3.820495501612568*^9, 
   3.827248514287983*^9},
 CellLabel->"Out[31]=",ExpressionUUID->"8fcc2c72-dae0-459a-8a61-f492e0ed5b22"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Dimensions", "Section",
 CellChangeTimes->{{3.818174791025922*^9, 3.818174798423671*^9}, {
  3.818328541646139*^9, 
  3.8183285433958583`*^9}},ExpressionUUID->"12058b57-b0be-416d-8d44-\
04d0ba4b9aac"],

Cell["\<\
Do these two ways: by extracting from coordinates and by formula.\
\>", "Text",
 CellChangeTimes->{{3.820494617231534*^9, 
  3.8204946509232597`*^9}},ExpressionUUID->"4dd759b2-4420-444e-a00e-\
14c2a898d6d9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"1", ",", "n"}], "]"}], "[", 
     RowBox[{"[", "3", "]"}], "]"}], ",", 
    RowBox[{"n", " ", 
     RowBox[{"Sin", "[", "theta", "]"}]}]}], "}"}], "//", "N", " ", 
  RowBox[{"(*", " ", 
   RowBox[{"pole", "-", "to", "-", 
    RowBox[{"pole", " ", "distance"}]}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.8183222852430196`*^9, 3.8183223808065243`*^9}},
 CellLabel->"In[32]:=",ExpressionUUID->"b1c46724-e5a7-4826-af82-86eead43836f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"5.196152422706632`", ",", "5.196152422706632`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.8183222925644093`*^9, {3.818322332417526*^9, 3.81832235409557*^9}, 
   3.818322417733765*^9, 3.818331360775977*^9, 3.8183428152243786`*^9, 
   3.820494606224616*^9, 3.820495360718404*^9, 3.8204955055115957`*^9, 
   3.8272485235468564`*^9},
 CellLabel->"Out[32]=",ExpressionUUID->"e350a15a-3046-44ea-94cc-700956db10b7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Norm", "[", 
     RowBox[{
      RowBox[{"v", "[", 
       RowBox[{"1", ",", 
        RowBox[{"n", "/", "2"}]}], "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}], "]"}], "]"}], "]"}], ",", " ", 
    RowBox[{
     RowBox[{"Cos", "[", "theta", "]"}], "/", 
     RowBox[{"Sin", "[", 
      RowBox[{"Pi", "/", "n"}], "]"}]}]}], "}"}], "//", "N", " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"max", " ", "radius"}], ",", " ", 
    RowBox[{"assuming", " ", "n", " ", "even"}]}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.8183226088323374`*^9, 3.8183226622661905`*^9}, {
  3.818322940066064*^9, 3.8183229409305067`*^9}, {3.818322986561931*^9, 
  3.8183229867405796`*^9}},
 CellLabel->"In[33]:=",ExpressionUUID->"7f4abe41-70b5-4c16-8451-4482d6438dbf"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2.351008204917142`", ",", "2.387276296034602`"}], "}"}]], "Output",
 CellChangeTimes->{{3.818322618195956*^9, 3.8183226260802193`*^9}, 
   3.818322663519755*^9, 3.818322942118496*^9, {3.8183229801265063`*^9, 
   3.8183229874105883`*^9}, 3.8183313636826653`*^9, 3.8183428180764256`*^9, 
   3.820495363308627*^9, 3.8204955084021535`*^9, 3.827248531369554*^9},
 CellLabel->"Out[33]=",ExpressionUUID->"af64e56e-171f-4fb0-8ba2-c70b091c4d2e"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Find Angle for Maximum Volume", "Section",
 CellChangeTimes->{{3.818174791025922*^9, 3.818174798423671*^9}, {
  3.818255755871834*^9, 3.8182557764942985`*^9}, {3.818328380986189*^9, 
  3.81832838113945*^9}},ExpressionUUID->"7feff062-53f2-41d7-9d02-\
cffbd414ae9d"],

Cell["\<\
Construct examples, calculate volumes, and look for maximum.  
Turns out to be 35.26, same as for pyramid, cone, and eutactic star.
Can derive that value via differentiation.\
\>", "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBmIQnfHIxdHw0WtH6bNxLiBaT73YG0RP/cHpA6JNDh2p
AdHV6fPqQfSyzNL73968dnzQt+0BiE67GfBm+8fXjlkhi96CaKFDX2JyE984
dlVGJoBoiYTYZ1OK3jhqRDu/BNE+hW7/QPS+7wfB9I8bhvOmAekLIj6LQfQx
uwtHdgLpsl+hF0B0zRLFbyDaQkHgL4iOuCkXuQtIl+91iQHRUudFk0F02WKN
bBD9e66m/24gffrWSjD9oP95CIh2uDM5BkSv8TpZ9AhIX0kXrQfRPzjMPzCX
v3H8oGz0FUQ/2cqjxAKktxWrqYLoa1dEDUC0drO1MYgGAARfpIU=
  "],ExpressionUUID->"2d85cb5c-92c0-447a-b6cb-642a70aa5716"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"(", " ", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"n", "=", "7"}], ";", "  ", 
     RowBox[{"(*", " ", 
      RowBox[{"can", " ", "try", " ", "for", " ", "any", " ", "n"}], " ", 
      "*)"}], "\[IndentingNewLine]", 
     RowBox[{"theta", "=", 
      RowBox[{"x", " ", "Degree"}]}], ";", 
     RowBox[{"pz", "=", 
      RowBox[{"ConvexHullMesh", "[", 
       RowBox[{
        RowBox[{"Flatten", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"v", "[", 
             RowBox[{"i", ",", "j"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", "n"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"j", ",", 
              RowBox[{"i", "-", "1"}], ",", 
              RowBox[{"i", "+", "n", "-", "1"}]}], "}"}]}], "]"}], ",", "1"}],
          "]"}], ",", 
        RowBox[{"PlotTheme", "\[Rule]", "\"\<Polygons\>\""}]}], "]"}]}], " ", 
     ";", 
     RowBox[{"Print", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"theta", "/", "Degree"}], ",", 
        RowBox[{"RegionMeasure", "[", "pz", "]"}]}], "}"}], "]"}], ";"}], 
    "\[IndentingNewLine]", ")"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "35", ",", "35.5", ",", ".05"}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.8182470598367043`*^9, 3.818247065902599*^9}, {
   3.8182472962842617`*^9, 3.818247304054063*^9}, {3.81825510609485*^9, 
   3.818255106395633*^9}, {3.818255227200038*^9, 3.8182552387221527`*^9}, {
   3.8182552766753855`*^9, 3.818255295190321*^9}, {3.818255330129738*^9, 
   3.818255425676016*^9}, {3.8182554846780753`*^9, 3.818255506711692*^9}, {
   3.818255560666197*^9, 3.818255625404687*^9}, 3.818255696586871*^9, {
   3.818255779348518*^9, 3.818255793845503*^9}, {3.818255849016693*^9, 
   3.8182558491167293`*^9}, {3.818320583547249*^9, 3.818320603339645*^9}, {
   3.8183206585172215`*^9, 3.818320679303645*^9}, {3.818328829691199*^9, 
   3.8183288421130934`*^9}, {3.8183314103227296`*^9, 3.8183314142324343`*^9}, 
   3.818331601738085*^9, 3.820495114630105*^9, {3.820495156540098*^9, 
   3.8204951689826813`*^9}, {3.8272485674021783`*^9, 3.827248567770095*^9}},
 CellLabel->"In[34]:=",ExpressionUUID->"47eb2c83-5411-43d9-9a73-685a1d73e275"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"35.`", ",", "19.580457504217794`"}], "}"}]], "Print",
 CellChangeTimes->{3.8183206086901197`*^9, 3.8183313753268003`*^9, 
  3.818331417466778*^9, 3.8183428274951677`*^9, 3.820495368005453*^9, 
  3.820495512078141*^9, 3.827248689165891*^9},
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"d8e98888-fa13-4862-b5f0-fda80c07c8e4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"35.05`", ",", "19.58088651140651`"}], "}"}]], "Print",
 CellChangeTimes->{3.8183206086901197`*^9, 3.8183313753268003`*^9, 
  3.818331417466778*^9, 3.8183428274951677`*^9, 3.820495368005453*^9, 
  3.820495512078141*^9, 3.8272486891868954`*^9},
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"ec690b2f-989c-4c97-8f7e-ea2308211a2d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"35.1`", ",", "19.58122581328963`"}], "}"}]], "Print",
 CellChangeTimes->{3.8183206086901197`*^9, 3.8183313753268003`*^9, 
  3.818331417466778*^9, 3.8183428274951677`*^9, 3.820495368005453*^9, 
  3.820495512078141*^9, 3.827248689219903*^9},
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"c216b790-e53a-4d9d-b91b-25543d535955"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"35.15`", ",", "19.581475462881773`"}], "}"}]], "Print",
 CellChangeTimes->{3.8183206086901197`*^9, 3.8183313753268003`*^9, 
  3.818331417466778*^9, 3.8183428274951677`*^9, 3.820495368005453*^9, 
  3.820495512078141*^9, 3.827248689220904*^9},
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"91b3ea15-69c7-41c5-abcd-6dabf270a542"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"35.2`", ",", "19.58163551377807`"}], "}"}]], "Print",
 CellChangeTimes->{3.8183206086901197`*^9, 3.8183313753268003`*^9, 
  3.818331417466778*^9, 3.8183428274951677`*^9, 3.820495368005453*^9, 
  3.820495512078141*^9, 3.82724868924891*^9},
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"8643a22f-176d-4206-ab8a-5d409462de0d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"35.25`", ",", "19.58170602015378`"}], "}"}]], "Print",
 CellChangeTimes->{3.8183206086901197`*^9, 3.8183313753268003`*^9, 
  3.818331417466778*^9, 3.8183428274951677`*^9, 3.820495368005453*^9, 
  3.820495512078141*^9, 3.8272486892769156`*^9},
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"5029b517-c783-489d-96fd-4f17dc6cfa42"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"35.3`", ",", "19.581687036763878`"}], "}"}]], "Print",
 CellChangeTimes->{3.8183206086901197`*^9, 3.8183313753268003`*^9, 
  3.818331417466778*^9, 3.8183428274951677`*^9, 3.820495368005453*^9, 
  3.820495512078141*^9, 3.827248689277916*^9},
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"238a3555-9c69-4ccc-a788-784f18ba6f69"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"35.35`", ",", "19.58157861894264`"}], "}"}]], "Print",
 CellChangeTimes->{3.8183206086901197`*^9, 3.8183313753268003`*^9, 
  3.818331417466778*^9, 3.8183428274951677`*^9, 3.820495368005453*^9, 
  3.820495512078141*^9, 3.827248689307923*^9},
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"82253cf6-1989-4140-b6c0-99ac4280ada9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"35.4`", ",", "19.5813808226032`"}], "}"}]], "Print",
 CellChangeTimes->{3.8183206086901197`*^9, 3.8183313753268003`*^9, 
  3.818331417466778*^9, 3.8183428274951677`*^9, 3.820495368005453*^9, 
  3.820495512078141*^9, 3.8272486893109236`*^9},
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"ac953cf3-7f1a-47b7-b5c4-fe24ce728b0c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"35.45`", ",", "19.58109370423714`"}], "}"}]], "Print",
 CellChangeTimes->{3.8183206086901197`*^9, 3.8183313753268003`*^9, 
  3.818331417466778*^9, 3.8183428274951677`*^9, 3.820495368005453*^9, 
  3.820495512078141*^9, 3.82724868933893*^9},
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"5c2b4529-679c-4dc4-8dfe-2a6eac06cfc0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"35.5`", ",", "19.580717320914115`"}], "}"}]], "Print",
 CellChangeTimes->{3.8183206086901197`*^9, 3.8183313753268003`*^9, 
  3.818331417466778*^9, 3.8183428274951677`*^9, 3.820495368005453*^9, 
  3.820495512078141*^9, 3.8272486893439317`*^9},
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"52bd19ae-6a15-4596-8053-db4cafb0e7d5"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ArcTan", "[", 
    RowBox[{"1", "/", 
     RowBox[{"Sqrt", "[", "2", "]"}]}], "]"}], "/", "Degree"}], "//", "N", 
  "  ", 
  RowBox[{"(*", " ", 
   RowBox[{"Check", " ", "against", " ", "formula"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.81826273260423*^9, 3.818262752658573*^9}, {
  3.8204948654829273`*^9, 3.8204948704528418`*^9}, {3.8204949052724247`*^9, 
  3.820494909795751*^9}},ExpressionUUID->"a83a0ff7-70f8-4e86-a59f-\
2b53e158a7cb"],

Cell[BoxData["35.264389682754654`"], "Output",
 CellChangeTimes->{{3.818262748828576*^9, 3.818262753290879*^9}, 
   3.818342842154623*^9, 3.8204953730072303`*^9, 
   3.820495516188573*^9},ExpressionUUID->"fa4476a1-7539-4bb0-a1fd-\
381d18d3cfbf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", "th", "]"}], "^", "2"}], " ", 
        RowBox[{"Sin", "[", "th", "]"}]}], ",", "th"}], "]"}], "\[Equal]", 
     "0"}], "  ", ",", "th"}], "]"}], "  ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"derive", " ", "formula"}], ",", " ", 
    RowBox[{
    "knowing", " ", "volume", " ", "is", " ", "proportional", " ", "to", " ", 
     RowBox[{"r", "^", "2"}], " ", "*", " ", "length"}]}], " ", 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.8183189893298855`*^9, 3.8183189992114935`*^9}, {
   3.818342600587397*^9, 3.8183426085479593`*^9}, 3.818342711392462*^9, {
   3.818342900067512*^9, 3.818342907065028*^9}, 3.8183431656670585`*^9, {
   3.8204949512778606`*^9, 
   3.820494992967455*^9}},ExpressionUUID->"e7bfa2a2-2276-4d63-a5ef-\
f94f4cfb4d98"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"th", "\[Rule]", 
     RowBox[{"ConditionalExpression", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["\[Pi]", "2"]}], "+", 
        RowBox[{"2", " ", "\[Pi]", " ", 
         RowBox[{"C", "[", "1", "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"C", "[", "1", "]"}], "\[Element]", "Integers"}]}], "]"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"th", "\[Rule]", 
     RowBox[{"ConditionalExpression", "[", 
      RowBox[{
       RowBox[{
        FractionBox["\[Pi]", "2"], "+", 
        RowBox[{"2", " ", "\[Pi]", " ", 
         RowBox[{"C", "[", "1", "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"C", "[", "1", "]"}], "\[Element]", "Integers"}]}], "]"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"th", "\[Rule]", 
     RowBox[{"ConditionalExpression", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"ArcTan", "[", 
          FractionBox["1", 
           SqrtBox["2"]], "]"}]}], "+", 
        RowBox[{"2", " ", "\[Pi]", " ", 
         RowBox[{"C", "[", "1", "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"C", "[", "1", "]"}], "\[Element]", "Integers"}]}], "]"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"th", "\[Rule]", 
     RowBox[{"ConditionalExpression", "[", 
      RowBox[{
       RowBox[{"\[Pi]", "-", 
        RowBox[{"ArcTan", "[", 
         FractionBox["1", 
          SqrtBox["2"]], "]"}], "+", 
        RowBox[{"2", " ", "\[Pi]", " ", 
         RowBox[{"C", "[", "1", "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"C", "[", "1", "]"}], "\[Element]", "Integers"}]}], "]"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"th", "\[Rule]", 
     RowBox[{"ConditionalExpression", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"ArcTan", "[", 
         FractionBox["1", 
          SqrtBox["2"]], "]"}], "+", 
        RowBox[{"2", " ", "\[Pi]", " ", 
         RowBox[{"C", "[", "1", "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"C", "[", "1", "]"}], "\[Element]", "Integers"}]}], "]"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"th", "\[Rule]", 
     RowBox[{"ConditionalExpression", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "\[Pi]"}], "+", 
        RowBox[{"ArcTan", "[", 
         FractionBox["1", 
          SqrtBox["2"]], "]"}], "+", 
        RowBox[{"2", " ", "\[Pi]", " ", 
         RowBox[{"C", "[", "1", "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"C", "[", "1", "]"}], "\[Element]", "Integers"}]}], "]"}]}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.818319000899479*^9, 3.8183426120023828`*^9, {3.818342702370552*^9, 
   3.818342712564558*^9}, 3.818342860555589*^9, 3.818342915497653*^9, 
   3.8183430136603003`*^9, 3.8183430492308044`*^9, 3.818343173279344*^9, 
   3.8204949537783003`*^9, 3.820495376429557*^9, 
   3.820495518943379*^9},ExpressionUUID->"018252ad-197f-4780-b796-\
f2dc9101f9cc"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Find Angle for Maximum Area", "Section",
 CellChangeTimes->{{3.818174791025922*^9, 3.818174798423671*^9}, {
   3.818255755871834*^9, 3.8182557764942985`*^9}, 
   3.8183284341710196`*^9},ExpressionUUID->"ead5b16b-7bd2-4289-81e3-\
d5d5525e1d7d"],

Cell["\<\
Construct examples, calculate areas, and look for maximum.  Turns out to be \
about 33.6 for large n.  Why? \
\>", "Text",
 CellChangeTimes->{{3.7424686181526375`*^9, 3.7424686429625373`*^9}, {
   3.7424686995985327`*^9, 3.7424687043115945`*^9}, {3.7424690941487064`*^9, 
   3.742469116950132*^9}, {3.7481162196691465`*^9, 3.748116229704941*^9}, {
   3.750608738526538*^9, 3.7506087490728045`*^9}, {3.80917629564869*^9, 
   3.8091763227960863`*^9}, {3.81817016291798*^9, 3.8181701861048775`*^9}, {
   3.81817035420133*^9, 3.818170358061492*^9}, {3.8181736815577354`*^9, 
   3.8181737223775406`*^9}, {3.818245670507663*^9, 3.818245762686824*^9}, {
   3.8182460650513287`*^9, 3.818246120503933*^9}, {3.818246856964031*^9, 
   3.818246882148128*^9}, {3.818246936681531*^9, 3.8182470012699537`*^9}, {
   3.8182488253005347`*^9, 3.818248829307958*^9}, {3.818248871236313*^9, 
   3.818248932620636*^9}, {3.818328982290365*^9, 3.8183290806689243`*^9}, {
   3.8183311455126734`*^9, 3.8183311835498977`*^9}, {3.8183315153256054`*^9, 
   3.8183315166651487`*^9}, {3.818342288766588*^9, 3.8183423818379536`*^9}, {
   3.818342543795024*^9, 3.81834254818739*^9}, 3.82049503662763*^9, {
   3.8204952242763577`*^9, 3.820495226480714*^9}, {3.826150986553155*^9, 
   3.8261509882944813`*^9}},ExpressionUUID->"26826e79-e1e0-4c0d-965c-\
ddbbd1522e25"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"(", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"n", "=", "25"}], ";", "\[IndentingNewLine]", 
     RowBox[{"theta", "=", 
      RowBox[{"x", " ", "Degree"}]}], ";", 
     RowBox[{"pz", "=", 
      RowBox[{"ConvexHullMesh", "[", 
       RowBox[{
        RowBox[{"Flatten", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"v", "[", 
             RowBox[{"i", ",", "j"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", "n"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"j", ",", 
              RowBox[{"i", "-", "1"}], ",", 
              RowBox[{"i", "+", "n", "-", "1"}]}], "}"}]}], "]"}], ",", "1"}],
          "]"}], ",", 
        RowBox[{"PlotTheme", "\[Rule]", "\"\<Polygons\>\""}]}], "]"}]}], " ", 
     ";", 
     RowBox[{"Print", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"theta", "/", "Degree"}], ",", 
        RowBox[{"Area", "[", 
         RowBox[{"RegionBoundary", "[", "pz", "]"}], "]"}]}], "}"}], "]"}], 
     ";"}], "\[IndentingNewLine]", ")"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "33.3", ",", "33.8", ",", ".1"}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.8182470598367043`*^9, 3.818247065902599*^9}, {
   3.8182472962842617`*^9, 3.818247304054063*^9}, {3.81825510609485*^9, 
   3.818255106395633*^9}, {3.818255227200038*^9, 3.8182552387221527`*^9}, {
   3.8182552766753855`*^9, 3.818255295190321*^9}, {3.818255330129738*^9, 
   3.818255425676016*^9}, {3.8182554846780753`*^9, 3.818255506711692*^9}, {
   3.818255560666197*^9, 3.818255625404687*^9}, 3.818255696586871*^9, {
   3.818255779348518*^9, 3.818255793845503*^9}, {3.818255849016693*^9, 
   3.8182558491167293`*^9}, {3.8183206374138565`*^9, 3.8183206560125875`*^9}, 
   3.818320686404369*^9, {3.8183212210228295`*^9, 3.8183212442596827`*^9}, {
   3.8183212849517727`*^9, 3.8183213392980537`*^9}, 3.818321376054988*^9, 
   3.8183214135976763`*^9, 3.8183214620640535`*^9, {3.8183311648545313`*^9, 
   3.818331172641728*^9}, {3.818342406671722*^9, 3.818342424791585*^9}, 
   3.8183424876769056`*^9, {3.8204954227206507`*^9, 
   3.8204954230126033`*^9}},ExpressionUUID->"ddabc69d-e5dc-45cc-80d1-\
7df830a031f1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"33.3`", ",", "476.4530379120842`"}], "}"}]], "Print",
 CellChangeTimes->{
  3.8183314980002613`*^9, 3.8183424289314227`*^9, {3.8183424634320803`*^9, 
   3.818342492617588*^9}, 3.82049539591606*^9, 3.820495428190806*^9, 
   3.820495525954584*^9},ExpressionUUID->"7ae5d8dd-e088-4745-91dc-\
0ce599eaf00f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"33.4`", ",", "476.4593869596165`"}], "}"}]], "Print",
 CellChangeTimes->{
  3.8183314980002613`*^9, 3.8183424289314227`*^9, {3.8183424634320803`*^9, 
   3.818342492617588*^9}, 3.82049539591606*^9, 3.820495428190806*^9, 
   3.820495527253262*^9},ExpressionUUID->"5e50b1c3-e7f9-4a17-94bb-\
e363a8121f4f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"33.5`", ",", "476.46284089812593`"}], "}"}]], "Print",
 CellChangeTimes->{
  3.8183314980002613`*^9, 3.8183424289314227`*^9, {3.8183424634320803`*^9, 
   3.818342492617588*^9}, 3.82049539591606*^9, 3.820495428190806*^9, 
   3.8204955285414033`*^9},ExpressionUUID->"b0d0ff03-89ae-4f50-a41b-\
2db309823f3d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"33.599999999999994`", ",", "476.4633920192303`"}], "}"}]], "Print",
 CellChangeTimes->{
  3.8183314980002613`*^9, 3.8183424289314227`*^9, {3.8183424634320803`*^9, 
   3.818342492617588*^9}, 3.82049539591606*^9, 3.820495428190806*^9, 
   3.8204955298682485`*^9},ExpressionUUID->"8d36c089-c913-4959-a920-\
24a4bf3e7741"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"33.699999999999996`", ",", "476.46103267016844`"}], "}"}]], "Print",
 CellChangeTimes->{
  3.8183314980002613`*^9, 3.8183424289314227`*^9, {3.8183424634320803`*^9, 
   3.818342492617588*^9}, 3.82049539591606*^9, 3.820495428190806*^9, 
   3.8204955312173805`*^9},ExpressionUUID->"19d47fec-3c97-48f5-adbd-\
408b05fa4ee4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"33.8`", ",", "476.4557552537234`"}], "}"}]], "Print",
 CellChangeTimes->{
  3.8183314980002613`*^9, 3.8183424289314227`*^9, {3.8183424634320803`*^9, 
   3.818342492617588*^9}, 3.82049539591606*^9, 3.820495428190806*^9, 
   3.820495532525964*^9},ExpressionUUID->"4a8dd59d-b3d4-4030-a478-\
fff6d8dcbfef"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1290, 932},
WindowMargins->{{Automatic, 243}, {18, Automatic}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowSelection->True,
Magnification->1.100000023841858,
FrontEndVersion->"12.2 for Microsoft Windows (64-bit) (December 12, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"be1c84ab-2fc1-4c8d-b358-69b7f5d86fca"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 257, 4, 107, "Title",ExpressionUUID->"5f92735f-b0fc-4fca-8341-d9dbb5db09b2"],
Cell[827, 28, 1196, 19, 65, "Text",ExpressionUUID->"9741cc49-005f-4c5c-87ca-55a0abe28021"],
Cell[CellGroupData[{
Cell[2048, 51, 11362, 226, 385, "Input",ExpressionUUID->"cc56daf7-85ec-4c21-a4a3-98dd1c8ed991"],
Cell[CellGroupData[{
Cell[13435, 281, 2027, 34, 23, "Print",ExpressionUUID->"d92343a6-712f-4134-8fc2-39ba16bcba0d"],
Cell[15465, 317, 2101, 35, 23, "Print",ExpressionUUID->"0b91bb84-2c1e-40ac-bcdd-b0a55688b8f2"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[17615, 358, 151, 3, 73, "Section",ExpressionUUID->"a49accf5-835d-4afc-b7b8-a1922f8b6cd0"],
Cell[17769, 363, 1119, 18, 65, "Text",ExpressionUUID->"0d5c0048-1123-4607-834f-fb69adcb6861"],
Cell[CellGroupData[{
Cell[18913, 385, 7270, 130, 99, "Input",ExpressionUUID->"c2ccea3a-b5f8-4086-88f1-aee45c0d9f24"],
Cell[26186, 517, 21031, 344, 395, "Output",ExpressionUUID->"20b64327-f6cf-4478-86b4-c00e3beb99fc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[47254, 866, 1085, 26, 55, "Input",ExpressionUUID->"6bdb4865-e543-4d46-a643-3268a68f3b2c"],
Cell[48342, 894, 67996, 1111, 138, "Output",ExpressionUUID->"8fcc2c72-dae0-459a-8a61-f492e0ed5b22"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[116387, 2011, 206, 4, 73, "Section",ExpressionUUID->"12058b57-b0be-416d-8d44-04d0ba4b9aac"],
Cell[116596, 2017, 217, 5, 39, "Text",ExpressionUUID->"4dd759b2-4420-444e-a00e-14c2a898d6d9"],
Cell[CellGroupData[{
Cell[116838, 2026, 540, 14, 32, "Input",ExpressionUUID->"b1c46724-e5a7-4826-af82-86eead43836f"],
Cell[117381, 2042, 450, 8, 36, "Output",ExpressionUUID->"e350a15a-3046-44ea-94cc-700956db10b7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[117868, 2055, 864, 23, 32, "Input",ExpressionUUID->"7f4abe41-70b5-4c16-8451-4482d6438dbf"],
Cell[118735, 2080, 476, 7, 36, "Output",ExpressionUUID->"af64e56e-171f-4fb0-8ba2-c70b091c4d2e"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[119260, 2093, 270, 4, 73, "Section",ExpressionUUID->"7feff062-53f2-41d7-9d02-cffbd414ae9d"],
Cell[119533, 2099, 654, 12, 90, "Text",ExpressionUUID->"2d85cb5c-92c0-447a-b6cb-642a70aa5716"],
Cell[CellGroupData[{
Cell[120212, 2115, 2298, 50, 143, "Input",ExpressionUUID->"47eb2c83-5411-43d9-9a73-685a1d73e275"],
Cell[CellGroupData[{
Cell[122535, 2169, 384, 8, 23, "Print",ExpressionUUID->"d8e98888-fa13-4862-b5f0-fda80c07c8e4"],
Cell[122922, 2179, 387, 8, 23, "Print",ExpressionUUID->"ec690b2f-989c-4c97-8f7e-ea2308211a2d"],
Cell[123312, 2189, 384, 8, 23, "Print",ExpressionUUID->"c216b790-e53a-4d9d-b91b-25543d535955"],
Cell[123699, 2199, 386, 8, 23, "Print",ExpressionUUID->"91b3ea15-69c7-41c5-abcd-6dabf270a542"],
Cell[124088, 2209, 383, 8, 23, "Print",ExpressionUUID->"8643a22f-176d-4206-ab8a-5d409462de0d"],
Cell[124474, 2219, 387, 8, 23, "Print",ExpressionUUID->"5029b517-c783-489d-96fd-4f17dc6cfa42"],
Cell[124864, 2229, 385, 8, 23, "Print",ExpressionUUID->"238a3555-9c69-4ccc-a788-784f18ba6f69"],
Cell[125252, 2239, 385, 8, 23, "Print",ExpressionUUID->"82253cf6-1989-4140-b6c0-99ac4280ada9"],
Cell[125640, 2249, 385, 8, 23, "Print",ExpressionUUID->"ac953cf3-7f1a-47b7-b5c4-fe24ce728b0c"],
Cell[126028, 2259, 384, 8, 23, "Print",ExpressionUUID->"5c2b4529-679c-4dc4-8dfe-2a6eac06cfc0"],
Cell[126415, 2269, 387, 8, 23, "Print",ExpressionUUID->"52bd19ae-6a15-4596-8053-db4cafb0e7d5"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[126851, 2283, 496, 12, 32, "Input",ExpressionUUID->"a83a0ff7-70f8-4e86-a59f-2b53e158a7cb"],
Cell[127350, 2297, 245, 4, 36, "Output",ExpressionUUID->"fa4476a1-7539-4bb0-a1fd-381d18d3cfbf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[127632, 2306, 922, 24, 32, "Input",ExpressionUUID->"e7bfa2a2-2276-4d63-a5ef-f94f4cfb4d98"],
Cell[128557, 2332, 2935, 86, 140, "Output",ExpressionUUID->"018252ad-197f-4780-b796-f2dc9101f9cc"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[131541, 2424, 249, 4, 73, "Section",ExpressionUUID->"ead5b16b-7bd2-4289-81e3-d5d5525e1d7d"],
Cell[131793, 2430, 1342, 20, 39, "Text",ExpressionUUID->"26826e79-e1e0-4c0d-965c-ddbbd1522e25"],
Cell[CellGroupData[{
Cell[133160, 2454, 2278, 50, 143, "Input",ExpressionUUID->"ddabc69d-e5dc-45cc-80d1-7df830a031f1"],
Cell[CellGroupData[{
Cell[135463, 2508, 342, 7, 23, "Print",ExpressionUUID->"7ae5d8dd-e088-4745-91dc-0ce599eaf00f"],
Cell[135808, 2517, 342, 7, 23, "Print",ExpressionUUID->"5e50b1c3-e7f9-4a17-94bb-e363a8121f4f"],
Cell[136153, 2526, 345, 7, 23, "Print",ExpressionUUID->"b0d0ff03-89ae-4f50-a41b-2db309823f3d"],
Cell[136501, 2535, 358, 7, 23, "Print",ExpressionUUID->"8d36c089-c913-4959-a920-24a4bf3e7741"],
Cell[136862, 2544, 359, 7, 23, "Print",ExpressionUUID->"19d47fec-3c97-48f5-adbd-408b05fa4ee4"],
Cell[137224, 2553, 342, 7, 23, "Print",ExpressionUUID->"4a8dd59d-b3d4-4030-a478-fff6d8dcbfef"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

